# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon SES"
prefix = "ses"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CloneReceiptRuleSet = Action("CloneReceiptRuleSet")
CreateConfigurationSet = Action("CreateConfigurationSet")
CreateConfigurationSetEventDestination = Action(
    "CreateConfigurationSetEventDestination"
)
CreateConfigurationSetTrackingOptions = Action("CreateConfigurationSetTrackingOptions")
CreateContact = Action("CreateContact")
CreateContactList = Action("CreateContactList")
CreateCustomVerificationEmailTemplate = Action("CreateCustomVerificationEmailTemplate")
CreateDedicatedIpPool = Action("CreateDedicatedIpPool")
CreateDeliverabilityTestReport = Action("CreateDeliverabilityTestReport")
CreateEmailIdentity = Action("CreateEmailIdentity")
CreateEmailIdentityPolicy = Action("CreateEmailIdentityPolicy")
CreateEmailTemplate = Action("CreateEmailTemplate")
CreateImportJob = Action("CreateImportJob")
CreateReceiptFilter = Action("CreateReceiptFilter")
CreateReceiptRule = Action("CreateReceiptRule")
CreateReceiptRuleSet = Action("CreateReceiptRuleSet")
CreateTemplate = Action("CreateTemplate")
DeleteConfigurationSet = Action("DeleteConfigurationSet")
DeleteConfigurationSetEventDestination = Action(
    "DeleteConfigurationSetEventDestination"
)
DeleteConfigurationSetTrackingOptions = Action("DeleteConfigurationSetTrackingOptions")
DeleteContact = Action("DeleteContact")
DeleteContactList = Action("DeleteContactList")
DeleteCustomVerificationEmailTemplate = Action("DeleteCustomVerificationEmailTemplate")
DeleteDedicatedIpPool = Action("DeleteDedicatedIpPool")
DeleteEmailIdentity = Action("DeleteEmailIdentity")
DeleteEmailIdentityPolicy = Action("DeleteEmailIdentityPolicy")
DeleteEmailTemplate = Action("DeleteEmailTemplate")
DeleteIdentity = Action("DeleteIdentity")
DeleteIdentityPolicy = Action("DeleteIdentityPolicy")
DeleteReceiptFilter = Action("DeleteReceiptFilter")
DeleteReceiptRule = Action("DeleteReceiptRule")
DeleteReceiptRuleSet = Action("DeleteReceiptRuleSet")
DeleteSuppressedDestination = Action("DeleteSuppressedDestination")
DeleteTemplate = Action("DeleteTemplate")
DeleteVerifiedEmailAddress = Action("DeleteVerifiedEmailAddress")
DescribeActiveReceiptRuleSet = Action("DescribeActiveReceiptRuleSet")
DescribeConfigurationSet = Action("DescribeConfigurationSet")
DescribeReceiptRule = Action("DescribeReceiptRule")
DescribeReceiptRuleSet = Action("DescribeReceiptRuleSet")
GetAccount = Action("GetAccount")
GetAccountSendingEnabled = Action("GetAccountSendingEnabled")
GetBlacklistReports = Action("GetBlacklistReports")
GetConfigurationSet = Action("GetConfigurationSet")
GetConfigurationSetEventDestinations = Action("GetConfigurationSetEventDestinations")
GetContact = Action("GetContact")
GetContactList = Action("GetContactList")
GetCustomVerificationEmailTemplate = Action("GetCustomVerificationEmailTemplate")
GetDedicatedIp = Action("GetDedicatedIp")
GetDedicatedIps = Action("GetDedicatedIps")
GetDeliverabilityDashboardOptions = Action("GetDeliverabilityDashboardOptions")
GetDeliverabilityTestReport = Action("GetDeliverabilityTestReport")
GetDomainDeliverabilityCampaign = Action("GetDomainDeliverabilityCampaign")
GetDomainStatisticsReport = Action("GetDomainStatisticsReport")
GetEmailIdentity = Action("GetEmailIdentity")
GetEmailIdentityPolicies = Action("GetEmailIdentityPolicies")
GetEmailTemplate = Action("GetEmailTemplate")
GetIdentityDkimAttributes = Action("GetIdentityDkimAttributes")
GetIdentityMailFromDomainAttributes = Action("GetIdentityMailFromDomainAttributes")
GetIdentityNotificationAttributes = Action("GetIdentityNotificationAttributes")
GetIdentityPolicies = Action("GetIdentityPolicies")
GetIdentityVerificationAttributes = Action("GetIdentityVerificationAttributes")
GetImportJob = Action("GetImportJob")
GetSendQuota = Action("GetSendQuota")
GetSendStatistics = Action("GetSendStatistics")
GetSuppressedDestination = Action("GetSuppressedDestination")
GetTemplate = Action("GetTemplate")
ListConfigurationSets = Action("ListConfigurationSets")
ListContactLists = Action("ListContactLists")
ListContacts = Action("ListContacts")
ListCustomVerificationEmailTemplates = Action("ListCustomVerificationEmailTemplates")
ListDedicatedIpPools = Action("ListDedicatedIpPools")
ListDeliverabilityTestReports = Action("ListDeliverabilityTestReports")
ListDomainDeliverabilityCampaigns = Action("ListDomainDeliverabilityCampaigns")
ListEmailIdentities = Action("ListEmailIdentities")
ListEmailTemplates = Action("ListEmailTemplates")
ListIdentities = Action("ListIdentities")
ListIdentityPolicies = Action("ListIdentityPolicies")
ListImportJobs = Action("ListImportJobs")
ListReceiptFilters = Action("ListReceiptFilters")
ListReceiptRuleSets = Action("ListReceiptRuleSets")
ListSuppressedDestinations = Action("ListSuppressedDestinations")
ListTagsForResource = Action("ListTagsForResource")
ListTemplates = Action("ListTemplates")
ListVerifiedEmailAddresses = Action("ListVerifiedEmailAddresses")
PutAccountDedicatedIpWarmupAttributes = Action("PutAccountDedicatedIpWarmupAttributes")
PutAccountDetails = Action("PutAccountDetails")
PutAccountSendingAttributes = Action("PutAccountSendingAttributes")
PutAccountSuppressionAttributes = Action("PutAccountSuppressionAttributes")
PutConfigurationSetDeliveryOptions = Action("PutConfigurationSetDeliveryOptions")
PutConfigurationSetReputationOptions = Action("PutConfigurationSetReputationOptions")
PutConfigurationSetSendingOptions = Action("PutConfigurationSetSendingOptions")
PutConfigurationSetSuppressionOptions = Action("PutConfigurationSetSuppressionOptions")
PutConfigurationSetTrackingOptions = Action("PutConfigurationSetTrackingOptions")
PutDedicatedIpInPool = Action("PutDedicatedIpInPool")
PutDedicatedIpWarmupAttributes = Action("PutDedicatedIpWarmupAttributes")
PutDeliverabilityDashboardOption = Action("PutDeliverabilityDashboardOption")
PutEmailIdentityConfigurationSetAttributes = Action(
    "PutEmailIdentityConfigurationSetAttributes"
)
PutEmailIdentityDkimAttributes = Action("PutEmailIdentityDkimAttributes")
PutEmailIdentityDkimSigningAttributes = Action("PutEmailIdentityDkimSigningAttributes")
PutEmailIdentityFeedbackAttributes = Action("PutEmailIdentityFeedbackAttributes")
PutEmailIdentityMailFromAttributes = Action("PutEmailIdentityMailFromAttributes")
PutIdentityPolicy = Action("PutIdentityPolicy")
PutSuppressedDestination = Action("PutSuppressedDestination")
ReorderReceiptRuleSet = Action("ReorderReceiptRuleSet")
SendBounce = Action("SendBounce")
SendBulkEmail = Action("SendBulkEmail")
SendBulkTemplatedEmail = Action("SendBulkTemplatedEmail")
SendCustomVerificationEmail = Action("SendCustomVerificationEmail")
SendEmail = Action("SendEmail")
SendRawEmail = Action("SendRawEmail")
SendTemplatedEmail = Action("SendTemplatedEmail")
SetActiveReceiptRuleSet = Action("SetActiveReceiptRuleSet")
SetIdentityDkimEnabled = Action("SetIdentityDkimEnabled")
SetIdentityFeedbackForwardingEnabled = Action("SetIdentityFeedbackForwardingEnabled")
SetIdentityHeadersInNotificationsEnabled = Action(
    "SetIdentityHeadersInNotificationsEnabled"
)
SetIdentityMailFromDomain = Action("SetIdentityMailFromDomain")
SetIdentityNotificationTopic = Action("SetIdentityNotificationTopic")
SetReceiptRulePosition = Action("SetReceiptRulePosition")
TagResource = Action("TagResource")
TestRenderEmailTemplate = Action("TestRenderEmailTemplate")
TestRenderTemplate = Action("TestRenderTemplate")
UntagResource = Action("UntagResource")
UpdateAccountSendingEnabled = Action("UpdateAccountSendingEnabled")
UpdateConfigurationSetEventDestination = Action(
    "UpdateConfigurationSetEventDestination"
)
UpdateConfigurationSetReputationMetricsEnabled = Action(
    "UpdateConfigurationSetReputationMetricsEnabled"
)
UpdateConfigurationSetSendingEnabled = Action("UpdateConfigurationSetSendingEnabled")
UpdateConfigurationSetTrackingOptions = Action("UpdateConfigurationSetTrackingOptions")
UpdateContact = Action("UpdateContact")
UpdateContactList = Action("UpdateContactList")
UpdateCustomVerificationEmailTemplate = Action("UpdateCustomVerificationEmailTemplate")
UpdateEmailIdentityPolicy = Action("UpdateEmailIdentityPolicy")
UpdateEmailTemplate = Action("UpdateEmailTemplate")
UpdateReceiptRule = Action("UpdateReceiptRule")
UpdateTemplate = Action("UpdateTemplate")
VerifyDomainDkim = Action("VerifyDomainDkim")
VerifyDomainIdentity = Action("VerifyDomainIdentity")
VerifyEmailAddress = Action("VerifyEmailAddress")
VerifyEmailIdentity = Action("VerifyEmailIdentity")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS IoT Core Device Advisor"
prefix = "iotdeviceadvisor"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateSuiteDefinition = Action("CreateSuiteDefinition")
DeleteSuiteDefinition = Action("DeleteSuiteDefinition")
GetEndpoint = Action("GetEndpoint")
GetSuiteDefinition = Action("GetSuiteDefinition")
GetSuiteRun = Action("GetSuiteRun")
GetSuiteRunReport = Action("GetSuiteRunReport")
ListSuiteDefinitions = Action("ListSuiteDefinitions")
ListSuiteRuns = Action("ListSuiteRuns")
ListTagsForResource = Action("ListTagsForResource")
ListTestCases = Action("ListTestCases")
StartSuiteRun = Action("StartSuiteRun")
StopSuiteRun = Action("StopSuiteRun")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateSuiteDefinition = Action("UpdateSuiteDefinition")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon SimpleDB"
prefix = "sdb"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchDeleteAttributes = Action("BatchDeleteAttributes")
BatchPutAttributes = Action("BatchPutAttributes")
CreateDomain = Action("CreateDomain")
DeleteAttributes = Action("DeleteAttributes")
DeleteDomain = Action("DeleteDomain")
DomainMetadata = Action("DomainMetadata")
GetAttributes = Action("GetAttributes")
ListDomains = Action("ListDomains")
PutAttributes = Action("PutAttributes")
Select = Action("Select")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Network Manager"
prefix = "networkmanager"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptAttachment = Action("AcceptAttachment")
AssociateConnectPeer = Action("AssociateConnectPeer")
AssociateCustomerGateway = Action("AssociateCustomerGateway")
AssociateLink = Action("AssociateLink")
AssociateTransitGatewayConnectPeer = Action("AssociateTransitGatewayConnectPeer")
CreateConnectAttachment = Action("CreateConnectAttachment")
CreateConnectPeer = Action("CreateConnectPeer")
CreateConnection = Action("CreateConnection")
CreateCoreNetwork = Action("CreateCoreNetwork")
CreateDevice = Action("CreateDevice")
CreateGlobalNetwork = Action("CreateGlobalNetwork")
CreateLink = Action("CreateLink")
CreateSite = Action("CreateSite")
CreateSiteToSiteVpnAttachment = Action("CreateSiteToSiteVpnAttachment")
CreateTransitGatewayPeering = Action("CreateTransitGatewayPeering")
CreateTransitGatewayRouteTableAttachment = Action(
    "CreateTransitGatewayRouteTableAttachment"
)
CreateVpcAttachment = Action("CreateVpcAttachment")
DeleteAttachment = Action("DeleteAttachment")
DeleteConnectPeer = Action("DeleteConnectPeer")
DeleteConnection = Action("DeleteConnection")
DeleteCoreNetwork = Action("DeleteCoreNetwork")
DeleteCoreNetworkPolicyVersion = Action("DeleteCoreNetworkPolicyVersion")
DeleteDevice = Action("DeleteDevice")
DeleteGlobalNetwork = Action("DeleteGlobalNetwork")
DeleteLink = Action("DeleteLink")
DeletePeering = Action("DeletePeering")
DeleteResourcePolicy = Action("DeleteResourcePolicy")
DeleteSite = Action("DeleteSite")
DeregisterTransitGateway = Action("DeregisterTransitGateway")
DescribeGlobalNetworks = Action("DescribeGlobalNetworks")
DisassociateConnectPeer = Action("DisassociateConnectPeer")
DisassociateCustomerGateway = Action("DisassociateCustomerGateway")
DisassociateLink = Action("DisassociateLink")
DisassociateTransitGatewayConnectPeer = Action("DisassociateTransitGatewayConnectPeer")
ExecuteCoreNetworkChangeSet = Action("ExecuteCoreNetworkChangeSet")
GetConnectAttachment = Action("GetConnectAttachment")
GetConnectPeer = Action("GetConnectPeer")
GetConnectPeerAssociations = Action("GetConnectPeerAssociations")
GetConnections = Action("GetConnections")
GetCoreNetwork = Action("GetCoreNetwork")
GetCoreNetworkChangeEvents = Action("GetCoreNetworkChangeEvents")
GetCoreNetworkChangeSet = Action("GetCoreNetworkChangeSet")
GetCoreNetworkPolicy = Action("GetCoreNetworkPolicy")
GetCustomerGatewayAssociations = Action("GetCustomerGatewayAssociations")
GetDevices = Action("GetDevices")
GetLinkAssociations = Action("GetLinkAssociations")
GetLinks = Action("GetLinks")
GetNetworkResourceCounts = Action("GetNetworkResourceCounts")
GetNetworkResourceRelationships = Action("GetNetworkResourceRelationships")
GetNetworkResources = Action("GetNetworkResources")
GetNetworkRoutes = Action("GetNetworkRoutes")
GetNetworkTelemetry = Action("GetNetworkTelemetry")
GetResourcePolicy = Action("GetResourcePolicy")
GetRouteAnalysis = Action("GetRouteAnalysis")
GetSiteToSiteVpnAttachment = Action("GetSiteToSiteVpnAttachment")
GetSites = Action("GetSites")
GetTransitGatewayConnectPeerAssociations = Action(
    "GetTransitGatewayConnectPeerAssociations"
)
GetTransitGatewayPeering = Action("GetTransitGatewayPeering")
GetTransitGatewayRegistrations = Action("GetTransitGatewayRegistrations")
GetTransitGatewayRouteTableAttachment = Action("GetTransitGatewayRouteTableAttachment")
GetVpcAttachment = Action("GetVpcAttachment")
ListAttachments = Action("ListAttachments")
ListConnectPeers = Action("ListConnectPeers")
ListCoreNetworkPolicyVersions = Action("ListCoreNetworkPolicyVersions")
ListCoreNetworks = Action("ListCoreNetworks")
ListOrganizationServiceAccessStatus = Action("ListOrganizationServiceAccessStatus")
ListPeerings = Action("ListPeerings")
ListTagsForResource = Action("ListTagsForResource")
PutCoreNetworkPolicy = Action("PutCoreNetworkPolicy")
PutResourcePolicy = Action("PutResourcePolicy")
RegisterTransitGateway = Action("RegisterTransitGateway")
RejectAttachment = Action("RejectAttachment")
RestoreCoreNetworkPolicyVersion = Action("RestoreCoreNetworkPolicyVersion")
StartOrganizationServiceAccessUpdate = Action("StartOrganizationServiceAccessUpdate")
StartRouteAnalysis = Action("StartRouteAnalysis")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateConnection = Action("UpdateConnection")
UpdateCoreNetwork = Action("UpdateCoreNetwork")
UpdateDevice = Action("UpdateDevice")
UpdateGlobalNetwork = Action("UpdateGlobalNetwork")
UpdateLink = Action("UpdateLink")
UpdateNetworkResourceMetadata = Action("UpdateNetworkResourceMetadata")
UpdateSite = Action("UpdateSite")
UpdateVpcAttachment = Action("UpdateVpcAttachment")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Interactive Video Service"
prefix = "ivs"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchGetChannel = Action("BatchGetChannel")
BatchGetStreamKey = Action("BatchGetStreamKey")
CreateChannel = Action("CreateChannel")
CreateRecordingConfiguration = Action("CreateRecordingConfiguration")
CreateStreamKey = Action("CreateStreamKey")
DeleteChannel = Action("DeleteChannel")
DeletePlaybackKeyPair = Action("DeletePlaybackKeyPair")
DeleteRecordingConfiguration = Action("DeleteRecordingConfiguration")
DeleteStreamKey = Action("DeleteStreamKey")
GetChannel = Action("GetChannel")
GetPlaybackKeyPair = Action("GetPlaybackKeyPair")
GetRecordingConfiguration = Action("GetRecordingConfiguration")
GetStream = Action("GetStream")
GetStreamKey = Action("GetStreamKey")
GetStreamSession = Action("GetStreamSession")
ImportPlaybackKeyPair = Action("ImportPlaybackKeyPair")
ListChannels = Action("ListChannels")
ListPlaybackKeyPairs = Action("ListPlaybackKeyPairs")
ListRecordingConfigurations = Action("ListRecordingConfigurations")
ListStreamKeys = Action("ListStreamKeys")
ListStreamSessions = Action("ListStreamSessions")
ListStreams = Action("ListStreams")
ListTagsForResource = Action("ListTagsForResource")
PutMetadata = Action("PutMetadata")
StopStream = Action("StopStream")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateChannel = Action("UpdateChannel")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Database Query Metadata Service"
prefix = "dbqms"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateFavoriteQuery = Action("CreateFavoriteQuery")
CreateQueryHistory = Action("CreateQueryHistory")
CreateTab = Action("CreateTab")
DeleteFavoriteQueries = Action("DeleteFavoriteQueries")
DeleteQueryHistory = Action("DeleteQueryHistory")
DeleteTab = Action("DeleteTab")
DescribeFavoriteQueries = Action("DescribeFavoriteQueries")
DescribeQueryHistory = Action("DescribeQueryHistory")
DescribeTabs = Action("DescribeTabs")
GetQueryString = Action("GetQueryString")
UpdateFavoriteQuery = Action("UpdateFavoriteQuery")
UpdateQueryHistory = Action("UpdateQueryHistory")
UpdateTab = Action("UpdateTab")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Route 53"
prefix = "route53"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


ActivateKeySigningKey = Action("ActivateKeySigningKey")
AssociateVPCWithHostedZone = Action("AssociateVPCWithHostedZone")
ChangeCidrCollection = Action("ChangeCidrCollection")
ChangeResourceRecordSets = Action("ChangeResourceRecordSets")
ChangeTagsForResource = Action("ChangeTagsForResource")
CreateCidrCollection = Action("CreateCidrCollection")
CreateHealthCheck = Action("CreateHealthCheck")
CreateHostedZone = Action("CreateHostedZone")
CreateKeySigningKey = Action("CreateKeySigningKey")
CreateQueryLoggingConfig = Action("CreateQueryLoggingConfig")
CreateReusableDelegationSet = Action("CreateReusableDelegationSet")
CreateTrafficPolicy = Action("CreateTrafficPolicy")
CreateTrafficPolicyInstance = Action("CreateTrafficPolicyInstance")
CreateTrafficPolicyVersion = Action("CreateTrafficPolicyVersion")
CreateVPCAssociationAuthorization = Action("CreateVPCAssociationAuthorization")
DeactivateKeySigningKey = Action("DeactivateKeySigningKey")
DeleteCidrCollection = Action("DeleteCidrCollection")
DeleteHealthCheck = Action("DeleteHealthCheck")
DeleteHostedZone = Action("DeleteHostedZone")
DeleteKeySigningKey = Action("DeleteKeySigningKey")
DeleteQueryLoggingConfig = Action("DeleteQueryLoggingConfig")
DeleteReusableDelegationSet = Action("DeleteReusableDelegationSet")
DeleteTrafficPolicy = Action("DeleteTrafficPolicy")
DeleteTrafficPolicyInstance = Action("DeleteTrafficPolicyInstance")
DeleteVPCAssociationAuthorization = Action("DeleteVPCAssociationAuthorization")
DisableDomainAutoRenew = Action("DisableDomainAutoRenew")
DisableHostedZoneDNSSEC = Action("DisableHostedZoneDNSSEC")
DisassociateVPCFromHostedZone = Action("DisassociateVPCFromHostedZone")
EnableDomainAutoRenew = Action("EnableDomainAutoRenew")
EnableHostedZoneDNSSEC = Action("EnableHostedZoneDNSSEC")
GetAccountLimit = Action("GetAccountLimit")
GetChange = Action("GetChange")
GetCheckerIpRanges = Action("GetCheckerIpRanges")
GetDNSSEC = Action("GetDNSSEC")
GetGeoLocation = Action("GetGeoLocation")
GetHealthCheck = Action("GetHealthCheck")
GetHealthCheckCount = Action("GetHealthCheckCount")
GetHealthCheckLastFailureReason = Action("GetHealthCheckLastFailureReason")
GetHealthCheckStatus = Action("GetHealthCheckStatus")
GetHostedZone = Action("GetHostedZone")
GetHostedZoneCount = Action("GetHostedZoneCount")
GetHostedZoneLimit = Action("GetHostedZoneLimit")
GetQueryLoggingConfig = Action("GetQueryLoggingConfig")
GetReusableDelegationSet = Action("GetReusableDelegationSet")
GetReusableDelegationSetLimit = Action("GetReusableDelegationSetLimit")
GetTrafficPolicy = Action("GetTrafficPolicy")
GetTrafficPolicyInstance = Action("GetTrafficPolicyInstance")
GetTrafficPolicyInstanceCount = Action("GetTrafficPolicyInstanceCount")
ListCidrBlocks = Action("ListCidrBlocks")
ListCidrCollections = Action("ListCidrCollections")
ListCidrLocations = Action("ListCidrLocations")
ListGeoLocations = Action("ListGeoLocations")
ListHealthChecks = Action("ListHealthChecks")
ListHostedZones = Action("ListHostedZones")
ListHostedZonesByName = Action("ListHostedZonesByName")
ListHostedZonesByVPC = Action("ListHostedZonesByVPC")
ListQueryLoggingConfigs = Action("ListQueryLoggingConfigs")
ListResourceRecordSets = Action("ListResourceRecordSets")
ListReusableDelegationSets = Action("ListReusableDelegationSets")
ListTagsForResource = Action("ListTagsForResource")
ListTagsForResources = Action("ListTagsForResources")
ListTrafficPolicies = Action("ListTrafficPolicies")
ListTrafficPolicyInstances = Action("ListTrafficPolicyInstances")
ListTrafficPolicyInstancesByHostedZone = Action(
    "ListTrafficPolicyInstancesByHostedZone"
)
ListTrafficPolicyInstancesByPolicy = Action("ListTrafficPolicyInstancesByPolicy")
ListTrafficPolicyVersions = Action("ListTrafficPolicyVersions")
ListVPCAssociationAuthorizations = Action("ListVPCAssociationAuthorizations")
TestDNSAnswer = Action("TestDNSAnswer")
UpdateHealthCheck = Action("UpdateHealthCheck")
UpdateHostedZoneComment = Action("UpdateHostedZoneComment")
UpdateTrafficPolicyComment = Action("UpdateTrafficPolicyComment")
UpdateTrafficPolicyInstance = Action("UpdateTrafficPolicyInstance")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Mechanical Turk"
prefix = "mechanicalturk"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptQualificationRequest = Action("AcceptQualificationRequest")
ApproveAssignment = Action("ApproveAssignment")
ApproveRejectedAssignment = Action("ApproveRejectedAssignment")
AssignQualification = Action("AssignQualification")
AssociateQualificationWithWorker = Action("AssociateQualificationWithWorker")
BlockWorker = Action("BlockWorker")
ChangeHITTypeOfHIT = Action("ChangeHITTypeOfHIT")
CreateAdditionalAssignmentsForHIT = Action("CreateAdditionalAssignmentsForHIT")
CreateHIT = Action("CreateHIT")
CreateHITType = Action("CreateHITType")
CreateHITWithHITType = Action("CreateHITWithHITType")
CreateQualificationType = Action("CreateQualificationType")
CreateWorkerBlock = Action("CreateWorkerBlock")
DeleteHIT = Action("DeleteHIT")
DeleteQualificationType = Action("DeleteQualificationType")
DeleteWorkerBlock = Action("DeleteWorkerBlock")
DisableHIT = Action("DisableHIT")
DisassociateQualificationFromWorker = Action("DisassociateQualificationFromWorker")
DisposeHIT = Action("DisposeHIT")
DisposeQualificationType = Action("DisposeQualificationType")
ExtendHIT = Action("ExtendHIT")
ForceExpireHIT = Action("ForceExpireHIT")
GetAccountBalance = Action("GetAccountBalance")
GetAssignment = Action("GetAssignment")
GetAssignmentsForHIT = Action("GetAssignmentsForHIT")
GetBlockedWorkers = Action("GetBlockedWorkers")
GetBonusPayments = Action("GetBonusPayments")
GetFileUploadURL = Action("GetFileUploadURL")
GetHIT = Action("GetHIT")
GetHITsForQualificationType = Action("GetHITsForQualificationType")
GetQualificationRequests = Action("GetQualificationRequests")
GetQualificationScore = Action("GetQualificationScore")
GetQualificationType = Action("GetQualificationType")
GetQualificationsForQualificationType = Action("GetQualificationsForQualificationType")
GetRequesterStatistic = Action("GetRequesterStatistic")
GetRequesterWorkerStatistic = Action("GetRequesterWorkerStatistic")
GetReviewResultsForHIT = Action("GetReviewResultsForHIT")
GetReviewableHITs = Action("GetReviewableHITs")
GrantBonus = Action("GrantBonus")
GrantQualification = Action("GrantQualification")
ListAssignmentsForHIT = Action("ListAssignmentsForHIT")
ListBonusPayments = Action("ListBonusPayments")
ListHITs = Action("ListHITs")
ListHITsForQualificationType = Action("ListHITsForQualificationType")
ListQualificationRequests = Action("ListQualificationRequests")
ListQualificationTypes = Action("ListQualificationTypes")
ListReviewPolicyResultsForHIT = Action("ListReviewPolicyResultsForHIT")
ListReviewableHITs = Action("ListReviewableHITs")
ListWorkerBlocks = Action("ListWorkerBlocks")
ListWorkersWithQualificationType = Action("ListWorkersWithQualificationType")
NotifyWorkers = Action("NotifyWorkers")
RegisterHITType = Action("RegisterHITType")
RejectAssignment = Action("RejectAssignment")
RejectQualificationRequest = Action("RejectQualificationRequest")
RevokeQualification = Action("RevokeQualification")
SearchHITs = Action("SearchHITs")
SearchQualificationTypes = Action("SearchQualificationTypes")
SendBonus = Action("SendBonus")
SendTestEventNotification = Action("SendTestEventNotification")
SetHITAsReviewing = Action("SetHITAsReviewing")
SetHITTypeNotification = Action("SetHITTypeNotification")
UnblockWorker = Action("UnblockWorker")
UpdateExpirationForHIT = Action("UpdateExpirationForHIT")
UpdateHITReviewStatus = Action("UpdateHITReviewStatus")
UpdateHITTypeOfHIT = Action("UpdateHITTypeOfHIT")
UpdateNotificationSettings = Action("UpdateNotificationSettings")
UpdateQualificationScore = Action("UpdateQualificationScore")
UpdateQualificationType = Action("UpdateQualificationType")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon WorkLink"
prefix = "worklink"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateDomain = Action("AssociateDomain")
AssociateWebsiteAuthorizationProvider = Action("AssociateWebsiteAuthorizationProvider")
AssociateWebsiteCertificateAuthority = Action("AssociateWebsiteCertificateAuthority")
CreateFleet = Action("CreateFleet")
DeleteFleet = Action("DeleteFleet")
DescribeAuditStreamConfiguration = Action("DescribeAuditStreamConfiguration")
DescribeCompanyNetworkConfiguration = Action("DescribeCompanyNetworkConfiguration")
DescribeDevice = Action("DescribeDevice")
DescribeDevicePolicyConfiguration = Action("DescribeDevicePolicyConfiguration")
DescribeDomain = Action("DescribeDomain")
DescribeFleetMetadata = Action("DescribeFleetMetadata")
DescribeIdentityProviderConfiguration = Action("DescribeIdentityProviderConfiguration")
DescribeWebsiteCertificateAuthority = Action("DescribeWebsiteCertificateAuthority")
DisassociateDomain = Action("DisassociateDomain")
DisassociateWebsiteAuthorizationProvider = Action(
    "DisassociateWebsiteAuthorizationProvider"
)
DisassociateWebsiteCertificateAuthority = Action(
    "DisassociateWebsiteCertificateAuthority"
)
ListDevices = Action("ListDevices")
ListDomains = Action("ListDomains")
ListFleets = Action("ListFleets")
ListTagsForResource = Action("ListTagsForResource")
ListWebsiteAuthorizationProviders = Action("ListWebsiteAuthorizationProviders")
ListWebsiteCertificateAuthorities = Action("ListWebsiteCertificateAuthorities")
RestoreDomainAccess = Action("RestoreDomainAccess")
RevokeDomainAccess = Action("RevokeDomainAccess")
SearchEntity = Action("SearchEntity")
SignOutUser = Action("SignOutUser")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAuditStreamConfiguration = Action("UpdateAuditStreamConfiguration")
UpdateCompanyNetworkConfiguration = Action("UpdateCompanyNetworkConfiguration")
UpdateDevicePolicyConfiguration = Action("UpdateDevicePolicyConfiguration")
UpdateDomainMetadata = Action("UpdateDomainMetadata")
UpdateFleetMetadata = Action("UpdateFleetMetadata")
UpdateIdentityProviderConfiguration = Action("UpdateIdentityProviderConfiguration")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon SNS"
prefix = "sns"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddPermission = Action("AddPermission")
CheckIfPhoneNumberIsOptedOut = Action("CheckIfPhoneNumberIsOptedOut")
ConfirmSubscription = Action("ConfirmSubscription")
CreatePlatformApplication = Action("CreatePlatformApplication")
CreatePlatformEndpoint = Action("CreatePlatformEndpoint")
CreateSMSSandboxPhoneNumber = Action("CreateSMSSandboxPhoneNumber")
CreateTopic = Action("CreateTopic")
DeleteEndpoint = Action("DeleteEndpoint")
DeletePlatformApplication = Action("DeletePlatformApplication")
DeleteSMSSandboxPhoneNumber = Action("DeleteSMSSandboxPhoneNumber")
DeleteTopic = Action("DeleteTopic")
GetEndpointAttributes = Action("GetEndpointAttributes")
GetPlatformApplicationAttributes = Action("GetPlatformApplicationAttributes")
GetSMSAttributes = Action("GetSMSAttributes")
GetSMSSandboxAccountStatus = Action("GetSMSSandboxAccountStatus")
GetSubscriptionAttributes = Action("GetSubscriptionAttributes")
GetTopicAttributes = Action("GetTopicAttributes")
ListEndpointsByPlatformApplication = Action("ListEndpointsByPlatformApplication")
ListOriginationNumbers = Action("ListOriginationNumbers")
ListPhoneNumbersOptedOut = Action("ListPhoneNumbersOptedOut")
ListPlatformApplications = Action("ListPlatformApplications")
ListSMSSandboxPhoneNumbers = Action("ListSMSSandboxPhoneNumbers")
ListSubscriptions = Action("ListSubscriptions")
ListSubscriptionsByTopic = Action("ListSubscriptionsByTopic")
ListTagsForResource = Action("ListTagsForResource")
ListTopics = Action("ListTopics")
OptInPhoneNumber = Action("OptInPhoneNumber")
Publish = Action("Publish")
RemovePermission = Action("RemovePermission")
SetEndpointAttributes = Action("SetEndpointAttributes")
SetPlatformApplicationAttributes = Action("SetPlatformApplicationAttributes")
SetSMSAttributes = Action("SetSMSAttributes")
SetSubscriptionAttributes = Action("SetSubscriptionAttributes")
SetTopicAttributes = Action("SetTopicAttributes")
Subscribe = Action("Subscribe")
TagResource = Action("TagResource")
Unsubscribe = Action("Unsubscribe")
UntagResource = Action("UntagResource")
VerifySMSSandboxPhoneNumber = Action("VerifySMSSandboxPhoneNumber")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon S3 Object Lambda"
prefix = "s3-object-lambda"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AbortMultipartUpload = Action("AbortMultipartUpload")
DeleteObject = Action("DeleteObject")
DeleteObjectTagging = Action("DeleteObjectTagging")
DeleteObjectVersion = Action("DeleteObjectVersion")
DeleteObjectVersionTagging = Action("DeleteObjectVersionTagging")
GetObject = Action("GetObject")
GetObjectAcl = Action("GetObjectAcl")
GetObjectLegalHold = Action("GetObjectLegalHold")
GetObjectRetention = Action("GetObjectRetention")
GetObjectTagging = Action("GetObjectTagging")
GetObjectVersion = Action("GetObjectVersion")
GetObjectVersionAcl = Action("GetObjectVersionAcl")
GetObjectVersionTagging = Action("GetObjectVersionTagging")
ListBucket = Action("ListBucket")
ListBucketMultipartUploads = Action("ListBucketMultipartUploads")
ListBucketVersions = Action("ListBucketVersions")
ListMultipartUploadParts = Action("ListMultipartUploadParts")
PutObject = Action("PutObject")
PutObjectAcl = Action("PutObjectAcl")
PutObjectLegalHold = Action("PutObjectLegalHold")
PutObjectRetention = Action("PutObjectRetention")
PutObjectTagging = Action("PutObjectTagging")
PutObjectVersionAcl = Action("PutObjectVersionAcl")
PutObjectVersionTagging = Action("PutObjectVersionTagging")
RestoreObject = Action("RestoreObject")
WriteGetObjectResponse = Action("WriteGetObjectResponse")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS CodeStar"
prefix = "codestar"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateTeamMember = Action("AssociateTeamMember")
CreateProject = Action("CreateProject")
CreateUserProfile = Action("CreateUserProfile")
DeleteExtendedAccess = Action("DeleteExtendedAccess")
DeleteProject = Action("DeleteProject")
DeleteUserProfile = Action("DeleteUserProfile")
DescribeProject = Action("DescribeProject")
DescribeUserProfile = Action("DescribeUserProfile")
DisassociateTeamMember = Action("DisassociateTeamMember")
GetExtendedAccess = Action("GetExtendedAccess")
ListProjects = Action("ListProjects")
ListResources = Action("ListResources")
ListTagsForProject = Action("ListTagsForProject")
ListTeamMembers = Action("ListTeamMembers")
ListUserProfiles = Action("ListUserProfiles")
PutExtendedAccess = Action("PutExtendedAccess")
TagProject = Action("TagProject")
UntagProject = Action("UntagProject")
UpdateProject = Action("UpdateProject")
UpdateTeamMember = Action("UpdateTeamMember")
UpdateUserProfile = Action("UpdateUserProfile")
VerifyServiceRole = Action("VerifyServiceRole")



import unittest

from awacs.aws import BaseARN, Principal


class TestPrincipal(unittest.TestCase):
    def test_wildcard_principal(self):
        p = Principal("*")
        self.assertEqual(p.data, "*")
        with self.assertRaises(ValueError):
            p = Principal("*", "FAIL")

    def test_normal_principal(self):
        p = Principal("AWS", "arn:aws:iam::AccountNumber-WithoutHyphens:root")
        self.assertEqual(
            p.data, {"AWS": "arn:aws:iam::AccountNumber-WithoutHyphens:root"}
        )
        with self.assertRaises(ValueError):
            p = Principal("AWS")

    def test_invalid_principal_string(self):
        with self.assertRaises(ValueError):
            Principal("aws", "arn:aws:iam::AccountNumber-WithoutHyphens:root")


class TestBaseARN(unittest.TestCase):
    def test_aws(self):
        arn = BaseARN("service", "resource", "us-east-1", "account")
        self.assertEqual(arn.JSONrepr(), "arn:aws:service:us-east-1:account:resource")

    def test_cn(self):
        arn = BaseARN("service", "resource", "cn-north-1", "account")
        self.assertEqual(
            arn.JSONrepr(), "arn:aws-cn:service:cn-north-1:account:resource"
        )

    def test_gov(self):
        arn = BaseARN("service", "resource", "us-gov-west-1", "account")
        self.assertEqual(
            arn.JSONrepr(), "arn:aws-us-gov:service:us-gov-west-1:account:resource"
        )

    def test_dynamic(self):
        arn = BaseARN("service", "resource", "${AWS::Region}", "account")
        self.assertEqual(
            arn.JSONrepr(),
            "arn:${AWS::Partition}:service:${AWS::Region}:account:resource",
        )



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS IoT Core for LoRaWAN"
prefix = "iotwireless"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateAwsAccountWithPartnerAccount = Action("AssociateAwsAccountWithPartnerAccount")
AssociateMulticastGroupWithFuotaTask = Action("AssociateMulticastGroupWithFuotaTask")
AssociateWirelessDeviceWithFuotaTask = Action("AssociateWirelessDeviceWithFuotaTask")
AssociateWirelessDeviceWithMulticastGroup = Action(
    "AssociateWirelessDeviceWithMulticastGroup"
)
AssociateWirelessDeviceWithThing = Action("AssociateWirelessDeviceWithThing")
AssociateWirelessGatewayWithCertificate = Action(
    "AssociateWirelessGatewayWithCertificate"
)
AssociateWirelessGatewayWithThing = Action("AssociateWirelessGatewayWithThing")
CancelMulticastGroupSession = Action("CancelMulticastGroupSession")
CreateDestination = Action("CreateDestination")
CreateDeviceProfile = Action("CreateDeviceProfile")
CreateFuotaTask = Action("CreateFuotaTask")
CreateMulticastGroup = Action("CreateMulticastGroup")
CreateNetworkAnalyzerConfiguration = Action("CreateNetworkAnalyzerConfiguration")
CreateServiceProfile = Action("CreateServiceProfile")
CreateWirelessDevice = Action("CreateWirelessDevice")
CreateWirelessGateway = Action("CreateWirelessGateway")
CreateWirelessGatewayTask = Action("CreateWirelessGatewayTask")
CreateWirelessGatewayTaskDefinition = Action("CreateWirelessGatewayTaskDefinition")
DeleteDestination = Action("DeleteDestination")
DeleteDeviceProfile = Action("DeleteDeviceProfile")
DeleteFuotaTask = Action("DeleteFuotaTask")
DeleteMulticastGroup = Action("DeleteMulticastGroup")
DeleteNetworkAnalyzerConfiguration = Action("DeleteNetworkAnalyzerConfiguration")
DeleteQueuedMessages = Action("DeleteQueuedMessages")
DeleteServiceProfile = Action("DeleteServiceProfile")
DeleteWirelessDevice = Action("DeleteWirelessDevice")
DeleteWirelessGateway = Action("DeleteWirelessGateway")
DeleteWirelessGatewayTask = Action("DeleteWirelessGatewayTask")
DeleteWirelessGatewayTaskDefinition = Action("DeleteWirelessGatewayTaskDefinition")
DisassociateAwsAccountFromPartnerAccount = Action(
    "DisassociateAwsAccountFromPartnerAccount"
)
DisassociateMulticastGroupFromFuotaTask = Action(
    "DisassociateMulticastGroupFromFuotaTask"
)
DisassociateWirelessDeviceFromFuotaTask = Action(
    "DisassociateWirelessDeviceFromFuotaTask"
)
DisassociateWirelessDeviceFromMulticastGroup = Action(
    "DisassociateWirelessDeviceFromMulticastGroup"
)
DisassociateWirelessDeviceFromThing = Action("DisassociateWirelessDeviceFromThing")
DisassociateWirelessGatewayFromCertificate = Action(
    "DisassociateWirelessGatewayFromCertificate"
)
DisassociateWirelessGatewayFromThing = Action("DisassociateWirelessGatewayFromThing")
GetDestination = Action("GetDestination")
GetDeviceProfile = Action("GetDeviceProfile")
GetEventConfigurationByResourceTypes = Action("GetEventConfigurationByResourceTypes")
GetEventConfigurationsByResourceTypes = Action("GetEventConfigurationsByResourceTypes")
GetFuotaTask = Action("GetFuotaTask")
GetLogLevelsByResourceTypes = Action("GetLogLevelsByResourceTypes")
GetMulticastGroup = Action("GetMulticastGroup")
GetMulticastGroupSession = Action("GetMulticastGroupSession")
GetNetworkAnalyzerConfiguration = Action("GetNetworkAnalyzerConfiguration")
GetPartnerAccount = Action("GetPartnerAccount")
GetPosition = Action("GetPosition")
GetPositionConfiguration = Action("GetPositionConfiguration")
GetResourceEventConfiguration = Action("GetResourceEventConfiguration")
GetResourceLogLevel = Action("GetResourceLogLevel")
GetServiceEndpoint = Action("GetServiceEndpoint")
GetServiceProfile = Action("GetServiceProfile")
GetWirelessDevice = Action("GetWirelessDevice")
GetWirelessDeviceStatistics = Action("GetWirelessDeviceStatistics")
GetWirelessGateway = Action("GetWirelessGateway")
GetWirelessGatewayCertificate = Action("GetWirelessGatewayCertificate")
GetWirelessGatewayFirmwareInformation = Action("GetWirelessGatewayFirmwareInformation")
GetWirelessGatewayStatistics = Action("GetWirelessGatewayStatistics")
GetWirelessGatewayTask = Action("GetWirelessGatewayTask")
GetWirelessGatewayTaskDefinition = Action("GetWirelessGatewayTaskDefinition")
ListDestinations = Action("ListDestinations")
ListDeviceProfiles = Action("ListDeviceProfiles")
ListEventConfigurations = Action("ListEventConfigurations")
ListFuotaTasks = Action("ListFuotaTasks")
ListMulticastGroups = Action("ListMulticastGroups")
ListMulticastGroupsByFuotaTask = Action("ListMulticastGroupsByFuotaTask")
ListNetworkAnalyzerConfigurations = Action("ListNetworkAnalyzerConfigurations")
ListPartnerAccounts = Action("ListPartnerAccounts")
ListPositionConfigurations = Action("ListPositionConfigurations")
ListQueuedMessages = Action("ListQueuedMessages")
ListServiceProfiles = Action("ListServiceProfiles")
ListTagsForResource = Action("ListTagsForResource")
ListWirelessDevices = Action("ListWirelessDevices")
ListWirelessGatewayTaskDefinitions = Action("ListWirelessGatewayTaskDefinitions")
ListWirelessGateways = Action("ListWirelessGateways")
PutPositionConfiguration = Action("PutPositionConfiguration")
PutResourceLogLevel = Action("PutResourceLogLevel")
ResetAllResourceLogLevels = Action("ResetAllResourceLogLevels")
ResetResourceLogLevel = Action("ResetResourceLogLevel")
SendDataToMulticastGroup = Action("SendDataToMulticastGroup")
SendDataToWirelessDevice = Action("SendDataToWirelessDevice")
StartBulkAssociateWirelessDeviceWithMulticastGroup = Action(
    "StartBulkAssociateWirelessDeviceWithMulticastGroup"
)
StartBulkDisassociateWirelessDeviceFromMulticastGroup = Action(
    "StartBulkDisassociateWirelessDeviceFromMulticastGroup"
)
StartFuotaTask = Action("StartFuotaTask")
StartMulticastGroupSession = Action("StartMulticastGroupSession")
StartNetworkAnalyzerStream = Action("StartNetworkAnalyzerStream")
TagResource = Action("TagResource")
TestWirelessDevice = Action("TestWirelessDevice")
UntagResource = Action("UntagResource")
UpdateDestination = Action("UpdateDestination")
UpdateEventConfigurationByResourceTypes = Action(
    "UpdateEventConfigurationByResourceTypes"
)
UpdateEventConfigurationsByResourceTypes = Action(
    "UpdateEventConfigurationsByResourceTypes"
)
UpdateFuotaTask = Action("UpdateFuotaTask")
UpdateLogLevelsByResourceTypes = Action("UpdateLogLevelsByResourceTypes")
UpdateMulticastGroup = Action("UpdateMulticastGroup")
UpdateNetworkAnalyzerConfiguration = Action("UpdateNetworkAnalyzerConfiguration")
UpdatePartnerAccount = Action("UpdatePartnerAccount")
UpdatePosition = Action("UpdatePosition")
UpdateResourceEventConfiguration = Action("UpdateResourceEventConfiguration")
UpdateWirelessDevice = Action("UpdateWirelessDevice")
UpdateWirelessGateway = Action("UpdateWirelessGateway")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS SimScape"
prefix = "simscape"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


DeleteAgent = Action("DeleteAgent")
DeleteSimulation = Action("DeleteSimulation")
DescribeAgent = Action("DescribeAgent")
DescribeSimulation = Action("DescribeSimulation")
ListAgents = Action("ListAgents")
ListSimulations = Action("ListSimulations")
ListTagsForResource = Action("ListTagsForResource")
StartAgent = Action("StartAgent")
StartClock = Action("StartClock")
StartSimulation = Action("StartSimulation")
StopAgent = Action("StopAgent")
StopClock = Action("StopClock")
StopSimulation = Action("StopSimulation")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Elemental MediaConvert"
prefix = "mediaconvert"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateCertificate = Action("AssociateCertificate")
CancelJob = Action("CancelJob")
CreateJob = Action("CreateJob")
CreateJobTemplate = Action("CreateJobTemplate")
CreatePreset = Action("CreatePreset")
CreateQueue = Action("CreateQueue")
DeleteJobTemplate = Action("DeleteJobTemplate")
DeletePolicy = Action("DeletePolicy")
DeletePreset = Action("DeletePreset")
DeleteQueue = Action("DeleteQueue")
DescribeEndpoint = Action("DescribeEndpoint")
DescribeEndpoints = Action("DescribeEndpoints")
DisassociateCertificate = Action("DisassociateCertificate")
GetJob = Action("GetJob")
GetJobTemplate = Action("GetJobTemplate")
GetPolicy = Action("GetPolicy")
GetPreset = Action("GetPreset")
GetQueue = Action("GetQueue")
ListJobTemplates = Action("ListJobTemplates")
ListJobs = Action("ListJobs")
ListPresets = Action("ListPresets")
ListQueues = Action("ListQueues")
ListTagsForResource = Action("ListTagsForResource")
PutPolicy = Action("PutPolicy")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateJobTemplate = Action("UpdateJobTemplate")
UpdatePreset = Action("UpdatePreset")
UpdateQueue = Action("UpdateQueue")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Storage Gateway"
prefix = "storagegateway"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


ActivateGateway = Action("ActivateGateway")
AddCache = Action("AddCache")
AddTagsToResource = Action("AddTagsToResource")
AddUploadBuffer = Action("AddUploadBuffer")
AddWorkingStorage = Action("AddWorkingStorage")
AssignTapePool = Action("AssignTapePool")
AssociateFileSystem = Action("AssociateFileSystem")
AttachVolume = Action("AttachVolume")
BypassGovernanceRetention = Action("BypassGovernanceRetention")
CancelArchival = Action("CancelArchival")
CancelRetrieval = Action("CancelRetrieval")
CreateCachediSCSIVolume = Action("CreateCachediSCSIVolume")
CreateNFSFileShare = Action("CreateNFSFileShare")
CreateSMBFileShare = Action("CreateSMBFileShare")
CreateSnapshot = Action("CreateSnapshot")
CreateSnapshotFromVolumeRecoveryPoint = Action("CreateSnapshotFromVolumeRecoveryPoint")
CreateStorediSCSIVolume = Action("CreateStorediSCSIVolume")
CreateTapePool = Action("CreateTapePool")
CreateTapeWithBarcode = Action("CreateTapeWithBarcode")
CreateTapes = Action("CreateTapes")
DeleteAutomaticTapeCreationPolicy = Action("DeleteAutomaticTapeCreationPolicy")
DeleteBandwidthRateLimit = Action("DeleteBandwidthRateLimit")
DeleteChapCredentials = Action("DeleteChapCredentials")
DeleteFileShare = Action("DeleteFileShare")
DeleteGateway = Action("DeleteGateway")
DeleteSnapshotSchedule = Action("DeleteSnapshotSchedule")
DeleteTape = Action("DeleteTape")
DeleteTapeArchive = Action("DeleteTapeArchive")
DeleteTapePool = Action("DeleteTapePool")
DeleteVolume = Action("DeleteVolume")
DescribeAvailabilityMonitorTest = Action("DescribeAvailabilityMonitorTest")
DescribeBandwidthRateLimit = Action("DescribeBandwidthRateLimit")
DescribeBandwidthRateLimitSchedule = Action("DescribeBandwidthRateLimitSchedule")
DescribeCache = Action("DescribeCache")
DescribeCachediSCSIVolumes = Action("DescribeCachediSCSIVolumes")
DescribeChapCredentials = Action("DescribeChapCredentials")
DescribeFileSystemAssociations = Action("DescribeFileSystemAssociations")
DescribeGatewayInformation = Action("DescribeGatewayInformation")
DescribeMaintenanceStartTime = Action("DescribeMaintenanceStartTime")
DescribeNFSFileShares = Action("DescribeNFSFileShares")
DescribeSMBFileShares = Action("DescribeSMBFileShares")
DescribeSMBSettings = Action("DescribeSMBSettings")
DescribeSnapshotSchedule = Action("DescribeSnapshotSchedule")
DescribeStorediSCSIVolumes = Action("DescribeStorediSCSIVolumes")
DescribeTapeArchives = Action("DescribeTapeArchives")
DescribeTapeRecoveryPoints = Action("DescribeTapeRecoveryPoints")
DescribeTapes = Action("DescribeTapes")
DescribeUploadBuffer = Action("DescribeUploadBuffer")
DescribeVTLDevices = Action("DescribeVTLDevices")
DescribeWorkingStorage = Action("DescribeWorkingStorage")
DetachVolume = Action("DetachVolume")
DisableGateway = Action("DisableGateway")
DisassociateFileSystem = Action("DisassociateFileSystem")
JoinDomain = Action("JoinDomain")
ListAutomaticTapeCreationPolicies = Action("ListAutomaticTapeCreationPolicies")
ListFileShares = Action("ListFileShares")
ListFileSystemAssociations = Action("ListFileSystemAssociations")
ListGateways = Action("ListGateways")
ListLocalDisks = Action("ListLocalDisks")
ListTagsForResource = Action("ListTagsForResource")
ListTapePools = Action("ListTapePools")
ListTapes = Action("ListTapes")
ListVolumeInitiators = Action("ListVolumeInitiators")
ListVolumeRecoveryPoints = Action("ListVolumeRecoveryPoints")
ListVolumes = Action("ListVolumes")
NotifyWhenUploaded = Action("NotifyWhenUploaded")
RefreshCache = Action("RefreshCache")
RemoveTagsFromResource = Action("RemoveTagsFromResource")
ResetCache = Action("ResetCache")
RetrieveTapeArchive = Action("RetrieveTapeArchive")
RetrieveTapeRecoveryPoint = Action("RetrieveTapeRecoveryPoint")
SetLocalConsolePassword = Action("SetLocalConsolePassword")
SetSMBGuestPassword = Action("SetSMBGuestPassword")
ShutdownGateway = Action("ShutdownGateway")
StartAvailabilityMonitorTest = Action("StartAvailabilityMonitorTest")
StartGateway = Action("StartGateway")
UpdateAutomaticTapeCreationPolicy = Action("UpdateAutomaticTapeCreationPolicy")
UpdateBandwidthRateLimit = Action("UpdateBandwidthRateLimit")
UpdateBandwidthRateLimitSchedule = Action("UpdateBandwidthRateLimitSchedule")
UpdateChapCredentials = Action("UpdateChapCredentials")
UpdateFileSystemAssociation = Action("UpdateFileSystemAssociation")
UpdateGatewayInformation = Action("UpdateGatewayInformation")
UpdateGatewaySoftwareNow = Action("UpdateGatewaySoftwareNow")
UpdateMaintenanceStartTime = Action("UpdateMaintenanceStartTime")
UpdateNFSFileShare = Action("UpdateNFSFileShare")
UpdateSMBFileShare = Action("UpdateSMBFileShare")
UpdateSMBFileShareVisibility = Action("UpdateSMBFileShareVisibility")
UpdateSMBLocalGroups = Action("UpdateSMBLocalGroups")
UpdateSMBSecurityStrategy = Action("UpdateSMBSecurityStrategy")
UpdateSnapshotSchedule = Action("UpdateSnapshotSchedule")
UpdateVTLDeviceType = Action("UpdateVTLDeviceType")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Key Management Service"
prefix = "kms"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CancelKeyDeletion = Action("CancelKeyDeletion")
ConnectCustomKeyStore = Action("ConnectCustomKeyStore")
CreateAlias = Action("CreateAlias")
CreateCustomKeyStore = Action("CreateCustomKeyStore")
CreateGrant = Action("CreateGrant")
CreateKey = Action("CreateKey")
Decrypt = Action("Decrypt")
DeleteAlias = Action("DeleteAlias")
DeleteCustomKeyStore = Action("DeleteCustomKeyStore")
DeleteImportedKeyMaterial = Action("DeleteImportedKeyMaterial")
DescribeCustomKeyStores = Action("DescribeCustomKeyStores")
DescribeKey = Action("DescribeKey")
DisableKey = Action("DisableKey")
DisableKeyRotation = Action("DisableKeyRotation")
DisconnectCustomKeyStore = Action("DisconnectCustomKeyStore")
EnableKey = Action("EnableKey")
EnableKeyRotation = Action("EnableKeyRotation")
Encrypt = Action("Encrypt")
GenerateDataKey = Action("GenerateDataKey")
GenerateDataKeyPair = Action("GenerateDataKeyPair")
GenerateDataKeyPairWithoutPlaintext = Action("GenerateDataKeyPairWithoutPlaintext")
GenerateDataKeyWithoutPlaintext = Action("GenerateDataKeyWithoutPlaintext")
GenerateMac = Action("GenerateMac")
GenerateRandom = Action("GenerateRandom")
GetKeyPolicy = Action("GetKeyPolicy")
GetKeyRotationStatus = Action("GetKeyRotationStatus")
GetParametersForImport = Action("GetParametersForImport")
GetPublicKey = Action("GetPublicKey")
ImportKeyMaterial = Action("ImportKeyMaterial")
ListAliases = Action("ListAliases")
ListGrants = Action("ListGrants")
ListKeyPolicies = Action("ListKeyPolicies")
ListKeys = Action("ListKeys")
ListResourceTags = Action("ListResourceTags")
ListRetirableGrants = Action("ListRetirableGrants")
PutKeyPolicy = Action("PutKeyPolicy")
ReEncrypt = Action("ReEncrypt")
ReEncryptFrom = Action("ReEncryptFrom")
ReEncryptTo = Action("ReEncryptTo")
ReplicateKey = Action("ReplicateKey")
RetireGrant = Action("RetireGrant")
RevokeGrant = Action("RevokeGrant")
ScheduleKeyDeletion = Action("ScheduleKeyDeletion")
Sign = Action("Sign")
SynchronizeMultiRegionKey = Action("SynchronizeMultiRegionKey")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAlias = Action("UpdateAlias")
UpdateCustomKeyStore = Action("UpdateCustomKeyStore")
UpdateKeyDescription = Action("UpdateKeyDescription")
UpdatePrimaryRegion = Action("UpdatePrimaryRegion")
Verify = Action("Verify")
VerifyMac = Action("VerifyMac")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Control Tower"
prefix = "controltower"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateManagedAccount = Action("CreateManagedAccount")
DeregisterManagedAccount = Action("DeregisterManagedAccount")
DeregisterOrganizationalUnit = Action("DeregisterOrganizationalUnit")
DescribeAccountFactoryConfig = Action("DescribeAccountFactoryConfig")
DescribeCoreService = Action("DescribeCoreService")
DescribeGuardrail = Action("DescribeGuardrail")
DescribeGuardrailForTarget = Action("DescribeGuardrailForTarget")
DescribeManagedAccount = Action("DescribeManagedAccount")
DescribeManagedOrganizationalUnit = Action("DescribeManagedOrganizationalUnit")
DescribeSingleSignOn = Action("DescribeSingleSignOn")
DisableGuardrail = Action("DisableGuardrail")
EnableGuardrail = Action("EnableGuardrail")
GetAvailableUpdates = Action("GetAvailableUpdates")
GetGuardrailComplianceStatus = Action("GetGuardrailComplianceStatus")
GetHomeRegion = Action("GetHomeRegion")
GetLandingZoneStatus = Action("GetLandingZoneStatus")
ListDirectoryGroups = Action("ListDirectoryGroups")
ListEnabledGuardrails = Action("ListEnabledGuardrails")
ListGuardrailViolations = Action("ListGuardrailViolations")
ListGuardrails = Action("ListGuardrails")
ListGuardrailsForTarget = Action("ListGuardrailsForTarget")
ListManagedAccounts = Action("ListManagedAccounts")
ListManagedAccountsForGuardrail = Action("ListManagedAccountsForGuardrail")
ListManagedAccountsForParent = Action("ListManagedAccountsForParent")
ListManagedOrganizationalUnits = Action("ListManagedOrganizationalUnits")
ListManagedOrganizationalUnitsForGuardrail = Action(
    "ListManagedOrganizationalUnitsForGuardrail"
)
ManageOrganizationalUnit = Action("ManageOrganizationalUnit")
SetupLandingZone = Action("SetupLandingZone")
UpdateAccountFactoryConfig = Action("UpdateAccountFactoryConfig")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon MemoryDB"
prefix = "memorydb"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchUpdateCluster = Action("BatchUpdateCluster")
BatchUpdateClusters = Action("BatchUpdateClusters")
CopySnapshot = Action("CopySnapshot")
CreateAcl = Action("CreateAcl")
CreateCluster = Action("CreateCluster")
CreateParameterGroup = Action("CreateParameterGroup")
CreateSnapshot = Action("CreateSnapshot")
CreateSubnetGroup = Action("CreateSubnetGroup")
CreateUser = Action("CreateUser")
DeleteAcl = Action("DeleteAcl")
DeleteCluster = Action("DeleteCluster")
DeleteParameterGroup = Action("DeleteParameterGroup")
DeleteSnapshot = Action("DeleteSnapshot")
DeleteSubnetGroup = Action("DeleteSubnetGroup")
DeleteUser = Action("DeleteUser")
DescribeAcls = Action("DescribeAcls")
DescribeClusters = Action("DescribeClusters")
DescribeEngineVersions = Action("DescribeEngineVersions")
DescribeEvents = Action("DescribeEvents")
DescribeParameterGroups = Action("DescribeParameterGroups")
DescribeParameters = Action("DescribeParameters")
DescribeServiceUpdates = Action("DescribeServiceUpdates")
DescribeSnapshots = Action("DescribeSnapshots")
DescribeSubnetGroups = Action("DescribeSubnetGroups")
DescribeUsers = Action("DescribeUsers")
FailoverShard = Action("FailoverShard")
ListAllowedNodeTypeUpdates = Action("ListAllowedNodeTypeUpdates")
ListNodeTypeUpdates = Action("ListNodeTypeUpdates")
ListTags = Action("ListTags")
ResetParameterGroup = Action("ResetParameterGroup")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAcl = Action("UpdateAcl")
UpdateCluster = Action("UpdateCluster")
UpdateParameterGroup = Action("UpdateParameterGroup")
UpdateSubnetGroup = Action("UpdateSubnetGroup")
UpdateUser = Action("UpdateUser")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Chatbot"
prefix = "chatbot"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateChimeWebhookConfiguration = Action("CreateChimeWebhookConfiguration")
CreateSlackChannelConfiguration = Action("CreateSlackChannelConfiguration")
DeleteChimeWebhookConfiguration = Action("DeleteChimeWebhookConfiguration")
DeleteSlackChannelConfiguration = Action("DeleteSlackChannelConfiguration")
DeleteSlackUserIdentity = Action("DeleteSlackUserIdentity")
DeleteSlackWorkspaceAuthorization = Action("DeleteSlackWorkspaceAuthorization")
DescribeChimeWebhookConfigurations = Action("DescribeChimeWebhookConfigurations")
DescribeSlackChannelConfigurations = Action("DescribeSlackChannelConfigurations")
DescribeSlackChannels = Action("DescribeSlackChannels")
DescribeSlackUserIdentities = Action("DescribeSlackUserIdentities")
DescribeSlackWorkspaces = Action("DescribeSlackWorkspaces")
GetAccountPreferences = Action("GetAccountPreferences")
GetSlackOauthParameters = Action("GetSlackOauthParameters")
RedeemSlackOauthCode = Action("RedeemSlackOauthCode")
UpdateAccountPreferences = Action("UpdateAccountPreferences")
UpdateChimeWebhookConfiguration = Action("UpdateChimeWebhookConfiguration")
UpdateSlackChannelConfiguration = Action("UpdateSlackChannelConfiguration")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon DynamoDB Accelerator (DAX)"
prefix = "dax"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchGetItem = Action("BatchGetItem")
BatchWriteItem = Action("BatchWriteItem")
ConditionCheckItem = Action("ConditionCheckItem")
CreateCluster = Action("CreateCluster")
CreateParameterGroup = Action("CreateParameterGroup")
CreateSubnetGroup = Action("CreateSubnetGroup")
DecreaseReplicationFactor = Action("DecreaseReplicationFactor")
DefineAttributeList = Action("DefineAttributeList")
DefineAttributeListId = Action("DefineAttributeListId")
DefineKeySchema = Action("DefineKeySchema")
DeleteCluster = Action("DeleteCluster")
DeleteItem = Action("DeleteItem")
DeleteParameterGroup = Action("DeleteParameterGroup")
DeleteSubnetGroup = Action("DeleteSubnetGroup")
DescribeClusters = Action("DescribeClusters")
DescribeDefaultParameters = Action("DescribeDefaultParameters")
DescribeEvents = Action("DescribeEvents")
DescribeParameterGroups = Action("DescribeParameterGroups")
DescribeParameters = Action("DescribeParameters")
DescribeSubnetGroups = Action("DescribeSubnetGroups")
DescribeTable = Action("DescribeTable")
GetItem = Action("GetItem")
IncreaseReplicationFactor = Action("IncreaseReplicationFactor")
ListTables = Action("ListTables")
ListTags = Action("ListTags")
PutItem = Action("PutItem")
Query = Action("Query")
RebootNode = Action("RebootNode")
Scan = Action("Scan")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateCluster = Action("UpdateCluster")
UpdateItem = Action("UpdateItem")
UpdateParameterGroup = Action("UpdateParameterGroup")
UpdateSubnetGroup = Action("UpdateSubnetGroup")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Connect"
prefix = "connect"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateApprovedOrigin = Action("AssociateApprovedOrigin")
AssociateBot = Action("AssociateBot")
AssociateCustomerProfilesDomain = Action("AssociateCustomerProfilesDomain")
AssociateDefaultVocabulary = Action("AssociateDefaultVocabulary")
AssociateInstanceStorageConfig = Action("AssociateInstanceStorageConfig")
AssociateLambdaFunction = Action("AssociateLambdaFunction")
AssociateLexBot = Action("AssociateLexBot")
AssociatePhoneNumberContactFlow = Action("AssociatePhoneNumberContactFlow")
AssociateQueueQuickConnects = Action("AssociateQueueQuickConnects")
AssociateRoutingProfileQueues = Action("AssociateRoutingProfileQueues")
AssociateSecurityKey = Action("AssociateSecurityKey")
BatchAssociateAnalyticsDataSet = Action("BatchAssociateAnalyticsDataSet")
BatchDisassociateAnalyticsDataSet = Action("BatchDisassociateAnalyticsDataSet")
ClaimPhoneNumber = Action("ClaimPhoneNumber")
CreateAgentStatus = Action("CreateAgentStatus")
CreateContactFlow = Action("CreateContactFlow")
CreateContactFlowModule = Action("CreateContactFlowModule")
CreateHoursOfOperation = Action("CreateHoursOfOperation")
CreateInstance = Action("CreateInstance")
CreateIntegrationAssociation = Action("CreateIntegrationAssociation")
CreateQueue = Action("CreateQueue")
CreateQuickConnect = Action("CreateQuickConnect")
CreateRoutingProfile = Action("CreateRoutingProfile")
CreateSecurityProfile = Action("CreateSecurityProfile")
CreateTaskTemplate = Action("CreateTaskTemplate")
CreateUseCase = Action("CreateUseCase")
CreateUser = Action("CreateUser")
CreateUserHierarchyGroup = Action("CreateUserHierarchyGroup")
CreateVocabulary = Action("CreateVocabulary")
DeleteContactFlow = Action("DeleteContactFlow")
DeleteContactFlowModule = Action("DeleteContactFlowModule")
DeleteHoursOfOperation = Action("DeleteHoursOfOperation")
DeleteInstance = Action("DeleteInstance")
DeleteIntegrationAssociation = Action("DeleteIntegrationAssociation")
DeleteQuickConnect = Action("DeleteQuickConnect")
DeleteSecurityProfile = Action("DeleteSecurityProfile")
DeleteTaskTemplate = Action("DeleteTaskTemplate")
DeleteUseCase = Action("DeleteUseCase")
DeleteUser = Action("DeleteUser")
DeleteUserHierarchyGroup = Action("DeleteUserHierarchyGroup")
DeleteVocabulary = Action("DeleteVocabulary")
DescribeAgentStatus = Action("DescribeAgentStatus")
DescribeContact = Action("DescribeContact")
DescribeContactFlow = Action("DescribeContactFlow")
DescribeContactFlowModule = Action("DescribeContactFlowModule")
DescribeHoursOfOperation = Action("DescribeHoursOfOperation")
DescribeInstance = Action("DescribeInstance")
DescribeInstanceAttribute = Action("DescribeInstanceAttribute")
DescribeInstanceStorageConfig = Action("DescribeInstanceStorageConfig")
DescribePhoneNumber = Action("DescribePhoneNumber")
DescribeQueue = Action("DescribeQueue")
DescribeQuickConnect = Action("DescribeQuickConnect")
DescribeRoutingProfile = Action("DescribeRoutingProfile")
DescribeSecurityProfile = Action("DescribeSecurityProfile")
DescribeUser = Action("DescribeUser")
DescribeUserHierarchyGroup = Action("DescribeUserHierarchyGroup")
DescribeUserHierarchyStructure = Action("DescribeUserHierarchyStructure")
DescribeVocabulary = Action("DescribeVocabulary")
DestroyInstance = Action("DestroyInstance")
DisassociateApprovedOrigin = Action("DisassociateApprovedOrigin")
DisassociateBot = Action("DisassociateBot")
DisassociateCustomerProfilesDomain = Action("DisassociateCustomerProfilesDomain")
DisassociateInstanceStorageConfig = Action("DisassociateInstanceStorageConfig")
DisassociateLambdaFunction = Action("DisassociateLambdaFunction")
DisassociateLexBot = Action("DisassociateLexBot")
DisassociatePhoneNumberContactFlow = Action("DisassociatePhoneNumberContactFlow")
DisassociateQueueQuickConnects = Action("DisassociateQueueQuickConnects")
DisassociateRoutingProfileQueues = Action("DisassociateRoutingProfileQueues")
DisassociateSecurityKey = Action("DisassociateSecurityKey")
GetContactAttributes = Action("GetContactAttributes")
GetCurrentMetricData = Action("GetCurrentMetricData")
GetCurrentUserData = Action("GetCurrentUserData")
GetFederationToken = Action("GetFederationToken")
GetFederationTokens = Action("GetFederationTokens")
GetMetricData = Action("GetMetricData")
GetTaskTemplate = Action("GetTaskTemplate")
ListAgentStatuses = Action("ListAgentStatuses")
ListApprovedOrigins = Action("ListApprovedOrigins")
ListBots = Action("ListBots")
ListContactFlowModules = Action("ListContactFlowModules")
ListContactFlows = Action("ListContactFlows")
ListContactReferences = Action("ListContactReferences")
ListDefaultVocabularies = Action("ListDefaultVocabularies")
ListHoursOfOperations = Action("ListHoursOfOperations")
ListInstanceAttributes = Action("ListInstanceAttributes")
ListInstanceStorageConfigs = Action("ListInstanceStorageConfigs")
ListInstances = Action("ListInstances")
ListIntegrationAssociations = Action("ListIntegrationAssociations")
ListLambdaFunctions = Action("ListLambdaFunctions")
ListLexBots = Action("ListLexBots")
ListPhoneNumbers = Action("ListPhoneNumbers")
ListPhoneNumbersV2 = Action("ListPhoneNumbersV2")
ListPrompts = Action("ListPrompts")
ListQueueQuickConnects = Action("ListQueueQuickConnects")
ListQueues = Action("ListQueues")
ListQuickConnects = Action("ListQuickConnects")
ListRealtimeContactAnalysisSegments = Action("ListRealtimeContactAnalysisSegments")
ListRoutingProfileQueues = Action("ListRoutingProfileQueues")
ListRoutingProfiles = Action("ListRoutingProfiles")
ListSecurityKeys = Action("ListSecurityKeys")
ListSecurityProfilePermissions = Action("ListSecurityProfilePermissions")
ListSecurityProfiles = Action("ListSecurityProfiles")
ListTagsForResource = Action("ListTagsForResource")
ListTaskTemplates = Action("ListTaskTemplates")
ListUseCases = Action("ListUseCases")
ListUserHierarchyGroups = Action("ListUserHierarchyGroups")
ListUsers = Action("ListUsers")
ModifyInstance = Action("ModifyInstance")
PutUserStatus = Action("PutUserStatus")
ReleasePhoneNumber = Action("ReleasePhoneNumber")
ResumeContactRecording = Action("ResumeContactRecording")
SearchAvailablePhoneNumbers = Action("SearchAvailablePhoneNumbers")
SearchUsers = Action("SearchUsers")
SearchVocabularies = Action("SearchVocabularies")
StartChatContact = Action("StartChatContact")
StartContactRecording = Action("StartContactRecording")
StartContactStreaming = Action("StartContactStreaming")
StartOutboundVoiceContact = Action("StartOutboundVoiceContact")
StartTaskContact = Action("StartTaskContact")
StopContact = Action("StopContact")
StopContactRecording = Action("StopContactRecording")
StopContactStreaming = Action("StopContactStreaming")
SuspendContactRecording = Action("SuspendContactRecording")
TagResource = Action("TagResource")
TransferContact = Action("TransferContact")
UntagResource = Action("UntagResource")
UpdateAgentStatus = Action("UpdateAgentStatus")
UpdateContact = Action("UpdateContact")
UpdateContactAttributes = Action("UpdateContactAttributes")
UpdateContactFlowContent = Action("UpdateContactFlowContent")
UpdateContactFlowMetadata = Action("UpdateContactFlowMetadata")
UpdateContactFlowModuleContent = Action("UpdateContactFlowModuleContent")
UpdateContactFlowModuleMetadata = Action("UpdateContactFlowModuleMetadata")
UpdateContactFlowName = Action("UpdateContactFlowName")
UpdateContactSchedule = Action("UpdateContactSchedule")
UpdateHoursOfOperation = Action("UpdateHoursOfOperation")
UpdateInstanceAttribute = Action("UpdateInstanceAttribute")
UpdateInstanceStorageConfig = Action("UpdateInstanceStorageConfig")
UpdatePhoneNumber = Action("UpdatePhoneNumber")
UpdateQueueHoursOfOperation = Action("UpdateQueueHoursOfOperation")
UpdateQueueMaxContacts = Action("UpdateQueueMaxContacts")
UpdateQueueName = Action("UpdateQueueName")
UpdateQueueOutboundCallerConfig = Action("UpdateQueueOutboundCallerConfig")
UpdateQueueStatus = Action("UpdateQueueStatus")
UpdateQuickConnectConfig = Action("UpdateQuickConnectConfig")
UpdateQuickConnectName = Action("UpdateQuickConnectName")
UpdateRoutingProfileConcurrency = Action("UpdateRoutingProfileConcurrency")
UpdateRoutingProfileDefaultOutboundQueue = Action(
    "UpdateRoutingProfileDefaultOutboundQueue"
)
UpdateRoutingProfileName = Action("UpdateRoutingProfileName")
UpdateRoutingProfileQueues = Action("UpdateRoutingProfileQueues")
UpdateSecurityProfile = Action("UpdateSecurityProfile")
UpdateTaskTemplate = Action("UpdateTaskTemplate")
UpdateUserHierarchy = Action("UpdateUserHierarchy")
UpdateUserHierarchyGroupName = Action("UpdateUserHierarchyGroupName")
UpdateUserHierarchyStructure = Action("UpdateUserHierarchyStructure")
UpdateUserIdentityInfo = Action("UpdateUserIdentityInfo")
UpdateUserPhoneConfig = Action("UpdateUserPhoneConfig")
UpdateUserRoutingProfile = Action("UpdateUserRoutingProfile")
UpdateUserSecurityProfiles = Action("UpdateUserSecurityProfiles")
UpdatedescribeContent = Action("UpdatedescribeContent")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS AppSync"
prefix = "appsync"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateApi = Action("AssociateApi")
CreateApiCache = Action("CreateApiCache")
CreateApiKey = Action("CreateApiKey")
CreateDataSource = Action("CreateDataSource")
CreateDomainName = Action("CreateDomainName")
CreateFunction = Action("CreateFunction")
CreateGraphqlApi = Action("CreateGraphqlApi")
CreateResolver = Action("CreateResolver")
CreateType = Action("CreateType")
DeleteApiCache = Action("DeleteApiCache")
DeleteApiKey = Action("DeleteApiKey")
DeleteDataSource = Action("DeleteDataSource")
DeleteDomainName = Action("DeleteDomainName")
DeleteFunction = Action("DeleteFunction")
DeleteGraphqlApi = Action("DeleteGraphqlApi")
DeleteResolver = Action("DeleteResolver")
DeleteType = Action("DeleteType")
DisassociateApi = Action("DisassociateApi")
FlushApiCache = Action("FlushApiCache")
GetApiAssociation = Action("GetApiAssociation")
GetApiCache = Action("GetApiCache")
GetDataSource = Action("GetDataSource")
GetDomainName = Action("GetDomainName")
GetFunction = Action("GetFunction")
GetGraphqlApi = Action("GetGraphqlApi")
GetIntrospectionSchema = Action("GetIntrospectionSchema")
GetResolver = Action("GetResolver")
GetSchemaCreationStatus = Action("GetSchemaCreationStatus")
GetType = Action("GetType")
GraphQL = Action("GraphQL")
ListApiKeys = Action("ListApiKeys")
ListDataSources = Action("ListDataSources")
ListDomainNames = Action("ListDomainNames")
ListFunctions = Action("ListFunctions")
ListGraphqlApis = Action("ListGraphqlApis")
ListResolvers = Action("ListResolvers")
ListResolversByFunction = Action("ListResolversByFunction")
ListTagsForResource = Action("ListTagsForResource")
ListTypes = Action("ListTypes")
SetWebACL = Action("SetWebACL")
StartSchemaCreation = Action("StartSchemaCreation")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateApiCache = Action("UpdateApiCache")
UpdateApiKey = Action("UpdateApiKey")
UpdateDataSource = Action("UpdateDataSource")
UpdateDomainName = Action("UpdateDomainName")
UpdateFunction = Action("UpdateFunction")
UpdateGraphqlApi = Action("UpdateGraphqlApi")
UpdateResolver = Action("UpdateResolver")
UpdateType = Action("UpdateType")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon QuickSight"
prefix = "quicksight"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AccountConfigurations = Action("AccountConfigurations")
CancelIngestion = Action("CancelIngestion")
CreateAccountCustomization = Action("CreateAccountCustomization")
CreateAccountSubscription = Action("CreateAccountSubscription")
CreateAdmin = Action("CreateAdmin")
CreateAnalysis = Action("CreateAnalysis")
CreateCustomPermissions = Action("CreateCustomPermissions")
CreateDashboard = Action("CreateDashboard")
CreateDataSet = Action("CreateDataSet")
CreateDataSource = Action("CreateDataSource")
CreateEmailCustomizationTemplate = Action("CreateEmailCustomizationTemplate")
CreateFolder = Action("CreateFolder")
CreateFolderMembership = Action("CreateFolderMembership")
CreateGroup = Action("CreateGroup")
CreateGroupMembership = Action("CreateGroupMembership")
CreateIAMPolicyAssignment = Action("CreateIAMPolicyAssignment")
CreateIngestion = Action("CreateIngestion")
CreateNamespace = Action("CreateNamespace")
CreateReader = Action("CreateReader")
CreateTemplate = Action("CreateTemplate")
CreateTemplateAlias = Action("CreateTemplateAlias")
CreateTheme = Action("CreateTheme")
CreateThemeAlias = Action("CreateThemeAlias")
CreateUser = Action("CreateUser")
CreateVPCConnection = Action("CreateVPCConnection")
DeleteAccountCustomization = Action("DeleteAccountCustomization")
DeleteAnalysis = Action("DeleteAnalysis")
DeleteCustomPermissions = Action("DeleteCustomPermissions")
DeleteDashboard = Action("DeleteDashboard")
DeleteDataSet = Action("DeleteDataSet")
DeleteDataSource = Action("DeleteDataSource")
DeleteEmailCustomizationTemplate = Action("DeleteEmailCustomizationTemplate")
DeleteFolder = Action("DeleteFolder")
DeleteFolderMembership = Action("DeleteFolderMembership")
DeleteGroup = Action("DeleteGroup")
DeleteGroupMembership = Action("DeleteGroupMembership")
DeleteIAMPolicyAssignment = Action("DeleteIAMPolicyAssignment")
DeleteNamespace = Action("DeleteNamespace")
DeleteTemplate = Action("DeleteTemplate")
DeleteTemplateAlias = Action("DeleteTemplateAlias")
DeleteTheme = Action("DeleteTheme")
DeleteThemeAlias = Action("DeleteThemeAlias")
DeleteUser = Action("DeleteUser")
DeleteUserByPrincipalId = Action("DeleteUserByPrincipalId")
DeleteVPCConnection = Action("DeleteVPCConnection")
DescribeAccountCustomization = Action("DescribeAccountCustomization")
DescribeAccountSettings = Action("DescribeAccountSettings")
DescribeAccountSubscription = Action("DescribeAccountSubscription")
DescribeAnalysis = Action("DescribeAnalysis")
DescribeAnalysisPermissions = Action("DescribeAnalysisPermissions")
DescribeCustomPermissions = Action("DescribeCustomPermissions")
DescribeDashboard = Action("DescribeDashboard")
DescribeDashboardPermissions = Action("DescribeDashboardPermissions")
DescribeDataSet = Action("DescribeDataSet")
DescribeDataSetPermissions = Action("DescribeDataSetPermissions")
DescribeDataSource = Action("DescribeDataSource")
DescribeDataSourcePermissions = Action("DescribeDataSourcePermissions")
DescribeEmailCustomizationTemplate = Action("DescribeEmailCustomizationTemplate")
DescribeFolder = Action("DescribeFolder")
DescribeFolderPermissions = Action("DescribeFolderPermissions")
DescribeFolderResolvedPermissions = Action("DescribeFolderResolvedPermissions")
DescribeGroup = Action("DescribeGroup")
DescribeGroupMembership = Action("DescribeGroupMembership")
DescribeIAMPolicyAssignment = Action("DescribeIAMPolicyAssignment")
DescribeIngestion = Action("DescribeIngestion")
DescribeIpRestriction = Action("DescribeIpRestriction")
DescribeNamespace = Action("DescribeNamespace")
DescribeTemplate = Action("DescribeTemplate")
DescribeTemplateAlias = Action("DescribeTemplateAlias")
DescribeTemplatePermissions = Action("DescribeTemplatePermissions")
DescribeTheme = Action("DescribeTheme")
DescribeThemeAlias = Action("DescribeThemeAlias")
DescribeThemePermissions = Action("DescribeThemePermissions")
DescribeUser = Action("DescribeUser")
GenerateEmbedUrlForAnonymousUser = Action("GenerateEmbedUrlForAnonymousUser")
GenerateEmbedUrlForRegisteredUser = Action("GenerateEmbedUrlForRegisteredUser")
GetAnonymousUserEmbedUrl = Action("GetAnonymousUserEmbedUrl")
GetAuthCode = Action("GetAuthCode")
GetDashboardEmbedUrl = Action("GetDashboardEmbedUrl")
GetGroupMapping = Action("GetGroupMapping")
GetSessionEmbedUrl = Action("GetSessionEmbedUrl")
ListAnalyses = Action("ListAnalyses")
ListCustomPermissions = Action("ListCustomPermissions")
ListDashboardVersions = Action("ListDashboardVersions")
ListDashboards = Action("ListDashboards")
ListDataSets = Action("ListDataSets")
ListDataSources = Action("ListDataSources")
ListFolderMembers = Action("ListFolderMembers")
ListFolders = Action("ListFolders")
ListGroupMemberships = Action("ListGroupMemberships")
ListGroups = Action("ListGroups")
ListIAMPolicyAssignments = Action("ListIAMPolicyAssignments")
ListIAMPolicyAssignmentsForUser = Action("ListIAMPolicyAssignmentsForUser")
ListIngestions = Action("ListIngestions")
ListNamespaces = Action("ListNamespaces")
ListTagsForResource = Action("ListTagsForResource")
ListTemplateAliases = Action("ListTemplateAliases")
ListTemplateVersions = Action("ListTemplateVersions")
ListTemplates = Action("ListTemplates")
ListThemeAliases = Action("ListThemeAliases")
ListThemeVersions = Action("ListThemeVersions")
ListThemes = Action("ListThemes")
ListUserGroups = Action("ListUserGroups")
ListUsers = Action("ListUsers")
PassDataSet = Action("PassDataSet")
PassDataSource = Action("PassDataSource")
RegisterUser = Action("RegisterUser")
RestoreAnalysis = Action("RestoreAnalysis")
ScopeDownPolicy = Action("ScopeDownPolicy")
SearchAnalyses = Action("SearchAnalyses")
SearchDashboards = Action("SearchDashboards")
SearchDirectoryGroups = Action("SearchDirectoryGroups")
SearchFolders = Action("SearchFolders")
SearchGroups = Action("SearchGroups")
SetGroupMapping = Action("SetGroupMapping")
Subscribe = Action("Subscribe")
TagResource = Action("TagResource")
Unsubscribe = Action("Unsubscribe")
UntagResource = Action("UntagResource")
UpdateAccountCustomization = Action("UpdateAccountCustomization")
UpdateAccountSettings = Action("UpdateAccountSettings")
UpdateAnalysis = Action("UpdateAnalysis")
UpdateAnalysisPermissions = Action("UpdateAnalysisPermissions")
UpdateCustomPermissions = Action("UpdateCustomPermissions")
UpdateDashboard = Action("UpdateDashboard")
UpdateDashboardPermissions = Action("UpdateDashboardPermissions")
UpdateDashboardPublishedVersion = Action("UpdateDashboardPublishedVersion")
UpdateDataSet = Action("UpdateDataSet")
UpdateDataSetPermissions = Action("UpdateDataSetPermissions")
UpdateDataSource = Action("UpdateDataSource")
UpdateDataSourcePermissions = Action("UpdateDataSourcePermissions")
UpdateEmailCustomizationTemplate = Action("UpdateEmailCustomizationTemplate")
UpdateFolder = Action("UpdateFolder")
UpdateFolderPermissions = Action("UpdateFolderPermissions")
UpdateGroup = Action("UpdateGroup")
UpdateIAMPolicyAssignment = Action("UpdateIAMPolicyAssignment")
UpdateIpRestriction = Action("UpdateIpRestriction")
UpdatePublicSharingSettings = Action("UpdatePublicSharingSettings")
UpdateTemplate = Action("UpdateTemplate")
UpdateTemplateAlias = Action("UpdateTemplateAlias")
UpdateTemplatePermissions = Action("UpdateTemplatePermissions")
UpdateTheme = Action("UpdateTheme")
UpdateThemeAlias = Action("UpdateThemeAlias")
UpdateThemePermissions = Action("UpdateThemePermissions")
UpdateUser = Action("UpdateUser")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Fraud Detector"
prefix = "frauddetector"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchCreateVariable = Action("BatchCreateVariable")
BatchGetVariable = Action("BatchGetVariable")
CancelBatchImportJob = Action("CancelBatchImportJob")
CancelBatchPredictionJob = Action("CancelBatchPredictionJob")
CreateBatchImportJob = Action("CreateBatchImportJob")
CreateBatchPredictionJob = Action("CreateBatchPredictionJob")
CreateDetectorVersion = Action("CreateDetectorVersion")
CreateModel = Action("CreateModel")
CreateModelVersion = Action("CreateModelVersion")
CreateRule = Action("CreateRule")
CreateVariable = Action("CreateVariable")
DeleteBatchImportJob = Action("DeleteBatchImportJob")
DeleteBatchPredictionJob = Action("DeleteBatchPredictionJob")
DeleteDetector = Action("DeleteDetector")
DeleteDetectorVersion = Action("DeleteDetectorVersion")
DeleteEntityType = Action("DeleteEntityType")
DeleteEvent = Action("DeleteEvent")
DeleteEventType = Action("DeleteEventType")
DeleteEventsByEventType = Action("DeleteEventsByEventType")
DeleteExternalModel = Action("DeleteExternalModel")
DeleteLabel = Action("DeleteLabel")
DeleteModel = Action("DeleteModel")
DeleteModelVersion = Action("DeleteModelVersion")
DeleteOutcome = Action("DeleteOutcome")
DeleteRule = Action("DeleteRule")
DeleteVariable = Action("DeleteVariable")
DescribeDetector = Action("DescribeDetector")
DescribeModelVersions = Action("DescribeModelVersions")
GetBatchImportJobs = Action("GetBatchImportJobs")
GetBatchPredictionJobs = Action("GetBatchPredictionJobs")
GetDeleteEventsByEventTypeStatus = Action("GetDeleteEventsByEventTypeStatus")
GetDetectorVersion = Action("GetDetectorVersion")
GetDetectors = Action("GetDetectors")
GetEntityTypes = Action("GetEntityTypes")
GetEvent = Action("GetEvent")
GetEventPrediction = Action("GetEventPrediction")
GetEventPredictionMetadata = Action("GetEventPredictionMetadata")
GetEventTypes = Action("GetEventTypes")
GetExternalModels = Action("GetExternalModels")
GetKMSEncryptionKey = Action("GetKMSEncryptionKey")
GetLabels = Action("GetLabels")
GetModelVersion = Action("GetModelVersion")
GetModels = Action("GetModels")
GetOutcomes = Action("GetOutcomes")
GetRules = Action("GetRules")
GetVariables = Action("GetVariables")
ListEventPredictions = Action("ListEventPredictions")
ListTagsForResource = Action("ListTagsForResource")
PutDetector = Action("PutDetector")
PutEntityType = Action("PutEntityType")
PutEventType = Action("PutEventType")
PutExternalModel = Action("PutExternalModel")
PutKMSEncryptionKey = Action("PutKMSEncryptionKey")
PutLabel = Action("PutLabel")
PutOutcome = Action("PutOutcome")
SendEvent = Action("SendEvent")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateDetectorVersion = Action("UpdateDetectorVersion")
UpdateDetectorVersionMetadata = Action("UpdateDetectorVersionMetadata")
UpdateDetectorVersionStatus = Action("UpdateDetectorVersionStatus")
UpdateEventLabel = Action("UpdateEventLabel")
UpdateModel = Action("UpdateModel")
UpdateModelVersion = Action("UpdateModelVersion")
UpdateModelVersionStatus = Action("UpdateModelVersionStatus")
UpdateRuleMetadata = Action("UpdateRuleMetadata")
UpdateRuleVersion = Action("UpdateRuleVersion")
UpdateVariable = Action("UpdateVariable")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Mobile Hub"
prefix = "mobilehub"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateProject = Action("CreateProject")
CreateServiceRole = Action("CreateServiceRole")
DeleteProject = Action("DeleteProject")
DeleteProjectSnapshot = Action("DeleteProjectSnapshot")
DeployToStage = Action("DeployToStage")
DescribeBundle = Action("DescribeBundle")
ExportBundle = Action("ExportBundle")
ExportProject = Action("ExportProject")
GenerateProjectParameters = Action("GenerateProjectParameters")
GetProject = Action("GetProject")
GetProjectSnapshot = Action("GetProjectSnapshot")
ImportProject = Action("ImportProject")
InstallBundle = Action("InstallBundle")
ListAvailableConnectors = Action("ListAvailableConnectors")
ListAvailableFeatures = Action("ListAvailableFeatures")
ListAvailableRegions = Action("ListAvailableRegions")
ListBundles = Action("ListBundles")
ListProjectSnapshots = Action("ListProjectSnapshots")
ListProjects = Action("ListProjects")
SynchronizeProject = Action("SynchronizeProject")
UpdateProject = Action("UpdateProject")
ValidateProject = Action("ValidateProject")
VerifyServiceRole = Action("VerifyServiceRole")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS CodeDeploy secure host commands service"
prefix = "codedeploy-commands-secure"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


GetDeploymentSpecification = Action("GetDeploymentSpecification")
PollHostCommand = Action("PollHostCommand")
PutHostCommandAcknowledgement = Action("PutHostCommandAcknowledgement")
PutHostCommandComplete = Action("PutHostCommandComplete")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Fault Injection Simulator"
prefix = "fis"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateExperimentTemplate = Action("CreateExperimentTemplate")
DeleteExperimentTemplate = Action("DeleteExperimentTemplate")
GetAction = Action("GetAction")
GetExperiment = Action("GetExperiment")
GetExperimentTemplate = Action("GetExperimentTemplate")
GetTargetResourceType = Action("GetTargetResourceType")
InjectApiInternalError = Action("InjectApiInternalError")
InjectApiThrottleError = Action("InjectApiThrottleError")
InjectApiUnavailableError = Action("InjectApiUnavailableError")
ListActions = Action("ListActions")
ListExperimentTemplates = Action("ListExperimentTemplates")
ListExperiments = Action("ListExperiments")
ListTagsForResource = Action("ListTagsForResource")
ListTargetResourceTypes = Action("ListTargetResourceTypes")
StartExperiment = Action("StartExperiment")
StopExperiment = Action("StopExperiment")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateExperimentTemplate = Action("UpdateExperimentTemplate")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS IoT Things Graph"
prefix = "iotthingsgraph"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateEntityToThing = Action("AssociateEntityToThing")
CreateFlowTemplate = Action("CreateFlowTemplate")
CreateSystemInstance = Action("CreateSystemInstance")
CreateSystemTemplate = Action("CreateSystemTemplate")
DeleteFlowTemplate = Action("DeleteFlowTemplate")
DeleteNamespace = Action("DeleteNamespace")
DeleteSystemInstance = Action("DeleteSystemInstance")
DeleteSystemTemplate = Action("DeleteSystemTemplate")
DeploySystemInstance = Action("DeploySystemInstance")
DeprecateFlowTemplate = Action("DeprecateFlowTemplate")
DeprecateSystemTemplate = Action("DeprecateSystemTemplate")
DescribeNamespace = Action("DescribeNamespace")
DissociateEntityFromThing = Action("DissociateEntityFromThing")
GetEntities = Action("GetEntities")
GetFlowTemplate = Action("GetFlowTemplate")
GetFlowTemplateRevisions = Action("GetFlowTemplateRevisions")
GetNamespaceDeletionStatus = Action("GetNamespaceDeletionStatus")
GetSystemInstance = Action("GetSystemInstance")
GetSystemTemplate = Action("GetSystemTemplate")
GetSystemTemplateRevisions = Action("GetSystemTemplateRevisions")
GetUploadStatus = Action("GetUploadStatus")
ListFlowExecutionMessages = Action("ListFlowExecutionMessages")
ListTagsForResource = Action("ListTagsForResource")
SearchEntities = Action("SearchEntities")
SearchFlowExecutions = Action("SearchFlowExecutions")
SearchFlowTemplates = Action("SearchFlowTemplates")
SearchSystemInstances = Action("SearchSystemInstances")
SearchSystemTemplates = Action("SearchSystemTemplates")
SearchThings = Action("SearchThings")
TagResource = Action("TagResource")
UndeploySystemInstance = Action("UndeploySystemInstance")
UntagResource = Action("UntagResource")
UpdateFlowTemplate = Action("UpdateFlowTemplate")
UpdateSystemTemplate = Action("UpdateSystemTemplate")
UploadEntityDefinitions = Action("UploadEntityDefinitions")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS IoT RoboRunner"
prefix = "iotroborunner"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateAction = Action("CreateAction")
CreateActionTemplate = Action("CreateActionTemplate")
CreateActionTemplateDependency = Action("CreateActionTemplateDependency")
CreateActivity = Action("CreateActivity")
CreateActivityDependency = Action("CreateActivityDependency")
CreateDestination = Action("CreateDestination")
CreateDestinationRelationship = Action("CreateDestinationRelationship")
CreateSite = Action("CreateSite")
CreateTask = Action("CreateTask")
CreateTaskDependency = Action("CreateTaskDependency")
CreateWorker = Action("CreateWorker")
CreateWorkerFleet = Action("CreateWorkerFleet")
DeleteAction = Action("DeleteAction")
DeleteActionTemplate = Action("DeleteActionTemplate")
DeleteActionTemplateDependency = Action("DeleteActionTemplateDependency")
DeleteActivity = Action("DeleteActivity")
DeleteActivityDependency = Action("DeleteActivityDependency")
DeleteDestination = Action("DeleteDestination")
DeleteDestinationRelationship = Action("DeleteDestinationRelationship")
DeleteSite = Action("DeleteSite")
DeleteTask = Action("DeleteTask")
DeleteTaskDependency = Action("DeleteTaskDependency")
DeleteWorker = Action("DeleteWorker")
DeleteWorkerFleet = Action("DeleteWorkerFleet")
GetAction = Action("GetAction")
GetActionTemplate = Action("GetActionTemplate")
GetActivity = Action("GetActivity")
GetDestination = Action("GetDestination")
GetDestinationRelationship = Action("GetDestinationRelationship")
GetSite = Action("GetSite")
GetTask = Action("GetTask")
GetWorker = Action("GetWorker")
GetWorkerFleet = Action("GetWorkerFleet")
ListActionTemplates = Action("ListActionTemplates")
ListActions = Action("ListActions")
ListActivities = Action("ListActivities")
ListDestinationRelationships = Action("ListDestinationRelationships")
ListDestinations = Action("ListDestinations")
ListSites = Action("ListSites")
ListTasks = Action("ListTasks")
ListWorkerFleets = Action("ListWorkerFleets")
ListWorkers = Action("ListWorkers")
UpdateActionState = Action("UpdateActionState")
UpdateActivity = Action("UpdateActivity")
UpdateDestination = Action("UpdateDestination")
UpdateSite = Action("UpdateSite")
UpdateTask = Action("UpdateTask")
UpdateWorker = Action("UpdateWorker")
UpdateWorkerFleet = Action("UpdateWorkerFleet")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Forecast"
prefix = "forecast"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateAutoPredictor = Action("CreateAutoPredictor")
CreateDataset = Action("CreateDataset")
CreateDatasetGroup = Action("CreateDatasetGroup")
CreateDatasetImportJob = Action("CreateDatasetImportJob")
CreateExplainability = Action("CreateExplainability")
CreateExplainabilityExport = Action("CreateExplainabilityExport")
CreateForecast = Action("CreateForecast")
CreateForecastExportJob = Action("CreateForecastExportJob")
CreateMonitor = Action("CreateMonitor")
CreatePredictor = Action("CreatePredictor")
CreatePredictorBacktestExportJob = Action("CreatePredictorBacktestExportJob")
DeleteDataset = Action("DeleteDataset")
DeleteDatasetGroup = Action("DeleteDatasetGroup")
DeleteDatasetImportJob = Action("DeleteDatasetImportJob")
DeleteExplainability = Action("DeleteExplainability")
DeleteExplainabilityExport = Action("DeleteExplainabilityExport")
DeleteForecast = Action("DeleteForecast")
DeleteForecastExportJob = Action("DeleteForecastExportJob")
DeleteMonitor = Action("DeleteMonitor")
DeletePredictor = Action("DeletePredictor")
DeletePredictorBacktestExportJob = Action("DeletePredictorBacktestExportJob")
DeleteResourceTree = Action("DeleteResourceTree")
DescribeAutoPredictor = Action("DescribeAutoPredictor")
DescribeDataset = Action("DescribeDataset")
DescribeDatasetGroup = Action("DescribeDatasetGroup")
DescribeDatasetImportJob = Action("DescribeDatasetImportJob")
DescribeExplainability = Action("DescribeExplainability")
DescribeExplainabilityExport = Action("DescribeExplainabilityExport")
DescribeExplainablity = Action("DescribeExplainablity")
DescribeForecast = Action("DescribeForecast")
DescribeForecastExportJob = Action("DescribeForecastExportJob")
DescribeMonitor = Action("DescribeMonitor")
DescribePredictor = Action("DescribePredictor")
DescribePredictorBacktestExportJob = Action("DescribePredictorBacktestExportJob")
GetAccuracyMetrics = Action("GetAccuracyMetrics")
ListDatasetGroups = Action("ListDatasetGroups")
ListDatasetImportJobs = Action("ListDatasetImportJobs")
ListDatasets = Action("ListDatasets")
ListExplainabilities = Action("ListExplainabilities")
ListExplainabilityExports = Action("ListExplainabilityExports")
ListForecastExportJobs = Action("ListForecastExportJobs")
ListForecasts = Action("ListForecasts")
ListMonitorEvaluations = Action("ListMonitorEvaluations")
ListMonitors = Action("ListMonitors")
ListPredictorBacktestExportJobs = Action("ListPredictorBacktestExportJobs")
ListPredictors = Action("ListPredictors")
ListTagsForResource = Action("ListTagsForResource")
QueryForecast = Action("QueryForecast")
ResumeResource = Action("ResumeResource")
StopResource = Action("StopResource")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateDatasetGroup = Action("UpdateDatasetGroup")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Identity and Access Management Roles Anywhere"
prefix = "rolesanywhere"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateProfile = Action("CreateProfile")
CreateTrustAnchor = Action("CreateTrustAnchor")
DeleteCrl = Action("DeleteCrl")
DeleteProfile = Action("DeleteProfile")
DeleteTrustAnchor = Action("DeleteTrustAnchor")
DisableCrl = Action("DisableCrl")
DisableProfile = Action("DisableProfile")
DisableTrustAnchor = Action("DisableTrustAnchor")
EnableCrl = Action("EnableCrl")
EnableProfile = Action("EnableProfile")
EnableTrustAnchor = Action("EnableTrustAnchor")
GetCrl = Action("GetCrl")
GetProfile = Action("GetProfile")
GetSubject = Action("GetSubject")
GetTrustAnchor = Action("GetTrustAnchor")
ImportCrl = Action("ImportCrl")
ListCrls = Action("ListCrls")
ListProfiles = Action("ListProfiles")
ListSubjects = Action("ListSubjects")
ListTagsForResource = Action("ListTagsForResource")
ListTrustAnchors = Action("ListTrustAnchors")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateCrl = Action("UpdateCrl")
UpdateProfile = Action("UpdateProfile")
UpdateTrustAnchor = Action("UpdateTrustAnchor")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS CodeCommit"
prefix = "codecommit"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateApprovalRuleTemplateWithRepository = Action(
    "AssociateApprovalRuleTemplateWithRepository"
)
BatchAssociateApprovalRuleTemplateWithRepositories = Action(
    "BatchAssociateApprovalRuleTemplateWithRepositories"
)
BatchDescribeMergeConflicts = Action("BatchDescribeMergeConflicts")
BatchDisassociateApprovalRuleTemplateFromRepositories = Action(
    "BatchDisassociateApprovalRuleTemplateFromRepositories"
)
BatchGetCommits = Action("BatchGetCommits")
BatchGetPullRequests = Action("BatchGetPullRequests")
BatchGetRepositories = Action("BatchGetRepositories")
CancelUploadArchive = Action("CancelUploadArchive")
CreateApprovalRuleTemplate = Action("CreateApprovalRuleTemplate")
CreateBranch = Action("CreateBranch")
CreateCommit = Action("CreateCommit")
CreatePullRequest = Action("CreatePullRequest")
CreatePullRequestApprovalRule = Action("CreatePullRequestApprovalRule")
CreateRepository = Action("CreateRepository")
CreateUnreferencedMergeCommit = Action("CreateUnreferencedMergeCommit")
DeleteApprovalRuleTemplate = Action("DeleteApprovalRuleTemplate")
DeleteBranch = Action("DeleteBranch")
DeleteCommentContent = Action("DeleteCommentContent")
DeleteFile = Action("DeleteFile")
DeletePullRequestApprovalRule = Action("DeletePullRequestApprovalRule")
DeleteRepository = Action("DeleteRepository")
DescribeMergeConflicts = Action("DescribeMergeConflicts")
DescribePullRequestEvents = Action("DescribePullRequestEvents")
DisassociateApprovalRuleTemplateFromRepository = Action(
    "DisassociateApprovalRuleTemplateFromRepository"
)
EvaluatePullRequestApprovalRules = Action("EvaluatePullRequestApprovalRules")
GetApprovalRuleTemplate = Action("GetApprovalRuleTemplate")
GetBlob = Action("GetBlob")
GetBranch = Action("GetBranch")
GetComment = Action("GetComment")
GetCommentReactions = Action("GetCommentReactions")
GetCommentsForComparedCommit = Action("GetCommentsForComparedCommit")
GetCommentsForPullRequest = Action("GetCommentsForPullRequest")
GetCommit = Action("GetCommit")
GetCommitHistory = Action("GetCommitHistory")
GetCommitsFromMergeBase = Action("GetCommitsFromMergeBase")
GetDifferences = Action("GetDifferences")
GetFile = Action("GetFile")
GetFolder = Action("GetFolder")
GetMergeCommit = Action("GetMergeCommit")
GetMergeConflicts = Action("GetMergeConflicts")
GetMergeOptions = Action("GetMergeOptions")
GetObjectIdentifier = Action("GetObjectIdentifier")
GetPullRequest = Action("GetPullRequest")
GetPullRequestApprovalStates = Action("GetPullRequestApprovalStates")
GetPullRequestOverrideState = Action("GetPullRequestOverrideState")
GetReferences = Action("GetReferences")
GetRepository = Action("GetRepository")
GetRepositoryTriggers = Action("GetRepositoryTriggers")
GetTree = Action("GetTree")
GetUploadArchiveStatus = Action("GetUploadArchiveStatus")
GitPull = Action("GitPull")
GitPush = Action("GitPush")
ListApprovalRuleTemplates = Action("ListApprovalRuleTemplates")
ListAssociatedApprovalRuleTemplatesForRepository = Action(
    "ListAssociatedApprovalRuleTemplatesForRepository"
)
ListBranches = Action("ListBranches")
ListPullRequests = Action("ListPullRequests")
ListRepositories = Action("ListRepositories")
ListRepositoriesForApprovalRuleTemplate = Action(
    "ListRepositoriesForApprovalRuleTemplate"
)
ListTagsForResource = Action("ListTagsForResource")
MergeBranchesByFastForward = Action("MergeBranchesByFastForward")
MergeBranchesBySquash = Action("MergeBranchesBySquash")
MergeBranchesByThreeWay = Action("MergeBranchesByThreeWay")
MergePullRequestByFastForward = Action("MergePullRequestByFastForward")
MergePullRequestBySquash = Action("MergePullRequestBySquash")
MergePullRequestByThreeWay = Action("MergePullRequestByThreeWay")
OverridePullRequestApprovalRules = Action("OverridePullRequestApprovalRules")
PostCommentForComparedCommit = Action("PostCommentForComparedCommit")
PostCommentForPullRequest = Action("PostCommentForPullRequest")
PostCommentReply = Action("PostCommentReply")
PutCommentReaction = Action("PutCommentReaction")
PutFile = Action("PutFile")
PutRepositoryTriggers = Action("PutRepositoryTriggers")
TagResource = Action("TagResource")
TestRepositoryTriggers = Action("TestRepositoryTriggers")
UntagResource = Action("UntagResource")
UpdateApprovalRuleTemplateContent = Action("UpdateApprovalRuleTemplateContent")
UpdateApprovalRuleTemplateDescription = Action("UpdateApprovalRuleTemplateDescription")
UpdateApprovalRuleTemplateName = Action("UpdateApprovalRuleTemplateName")
UpdateComment = Action("UpdateComment")
UpdateDefaultBranch = Action("UpdateDefaultBranch")
UpdatePullRequestApprovalRuleContent = Action("UpdatePullRequestApprovalRuleContent")
UpdatePullRequestApprovalState = Action("UpdatePullRequestApprovalState")
UpdatePullRequestDescription = Action("UpdatePullRequestDescription")
UpdatePullRequestStatus = Action("UpdatePullRequestStatus")
UpdatePullRequestTitle = Action("UpdatePullRequestTitle")
UpdateRepositoryDescription = Action("UpdateRepositoryDescription")
UpdateRepositoryName = Action("UpdateRepositoryName")
UploadArchive = Action("UploadArchive")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Lookout for Metrics"
prefix = "lookoutmetrics"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


ActivateAnomalyDetector = Action("ActivateAnomalyDetector")
BackTestAnomalyDetector = Action("BackTestAnomalyDetector")
CreateAlert = Action("CreateAlert")
CreateAnomalyDetector = Action("CreateAnomalyDetector")
CreateMetricSet = Action("CreateMetricSet")
DeactivateAnomalyDetector = Action("DeactivateAnomalyDetector")
DeleteAlert = Action("DeleteAlert")
DeleteAnomalyDetector = Action("DeleteAnomalyDetector")
DescribeAlert = Action("DescribeAlert")
DescribeAnomalyDetectionExecutions = Action("DescribeAnomalyDetectionExecutions")
DescribeAnomalyDetector = Action("DescribeAnomalyDetector")
DescribeMetricSet = Action("DescribeMetricSet")
DetectMetricSetConfig = Action("DetectMetricSetConfig")
GetAnomalyGroup = Action("GetAnomalyGroup")
GetDataQualityMetrics = Action("GetDataQualityMetrics")
GetFeedback = Action("GetFeedback")
GetSampleData = Action("GetSampleData")
ListAlerts = Action("ListAlerts")
ListAnomalyDetectors = Action("ListAnomalyDetectors")
ListAnomalyGroupRelatedMetrics = Action("ListAnomalyGroupRelatedMetrics")
ListAnomalyGroupSummaries = Action("ListAnomalyGroupSummaries")
ListAnomalyGroupTimeSeries = Action("ListAnomalyGroupTimeSeries")
ListMetricSets = Action("ListMetricSets")
ListTagsForResource = Action("ListTagsForResource")
PutFeedback = Action("PutFeedback")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAlert = Action("UpdateAlert")
UpdateAnomalyDetector = Action("UpdateAnomalyDetector")
UpdateMetricSet = Action("UpdateMetricSet")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Connect Wisdom"
prefix = "wisdom"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateAssistant = Action("CreateAssistant")
CreateAssistantAssociation = Action("CreateAssistantAssociation")
CreateContent = Action("CreateContent")
CreateKnowledgeBase = Action("CreateKnowledgeBase")
CreateSession = Action("CreateSession")
DeleteAssistant = Action("DeleteAssistant")
DeleteAssistantAssociation = Action("DeleteAssistantAssociation")
DeleteContent = Action("DeleteContent")
DeleteKnowledgeBase = Action("DeleteKnowledgeBase")
GetAssistant = Action("GetAssistant")
GetAssistantAssociation = Action("GetAssistantAssociation")
GetContent = Action("GetContent")
GetContentSummary = Action("GetContentSummary")
GetKnowledgeBase = Action("GetKnowledgeBase")
GetRecommendations = Action("GetRecommendations")
GetSession = Action("GetSession")
ListAssistantAssociations = Action("ListAssistantAssociations")
ListAssistants = Action("ListAssistants")
ListContents = Action("ListContents")
ListKnowledgeBases = Action("ListKnowledgeBases")
ListTagsForResource = Action("ListTagsForResource")
NotifyRecommendationsReceived = Action("NotifyRecommendationsReceived")
QueryAssistant = Action("QueryAssistant")
RemoveKnowledgeBaseTemplateUri = Action("RemoveKnowledgeBaseTemplateUri")
SearchContent = Action("SearchContent")
SearchSessions = Action("SearchSessions")
StartContentUpload = Action("StartContentUpload")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateContent = Action("UpdateContent")
UpdateKnowledgeBaseTemplateUri = Action("UpdateKnowledgeBaseTemplateUri")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Migration Hub Orchestrator"
prefix = "migrationhub-orchestrator"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateWorkflow = Action("CreateWorkflow")
CreateWorkflowStep = Action("CreateWorkflowStep")
CreateWorkflowStepGroup = Action("CreateWorkflowStepGroup")
DeleteWorkflow = Action("DeleteWorkflow")
DeleteWorkflowStep = Action("DeleteWorkflowStep")
DeleteWorkflowStepGroup = Action("DeleteWorkflowStepGroup")
GetMessage = Action("GetMessage")
GetTemplate = Action("GetTemplate")
GetTemplateStep = Action("GetTemplateStep")
GetTemplateStepGroup = Action("GetTemplateStepGroup")
GetWorkflow = Action("GetWorkflow")
GetWorkflowStep = Action("GetWorkflowStep")
GetWorkflowStepGroup = Action("GetWorkflowStepGroup")
ListPlugins = Action("ListPlugins")
ListTagsForResource = Action("ListTagsForResource")
ListTemplateStepGroups = Action("ListTemplateStepGroups")
ListTemplateSteps = Action("ListTemplateSteps")
ListTemplates = Action("ListTemplates")
ListWorkflowStepGroups = Action("ListWorkflowStepGroups")
ListWorkflowSteps = Action("ListWorkflowSteps")
ListWorkflows = Action("ListWorkflows")
RegisterPlugin = Action("RegisterPlugin")
RetryWorkflowStep = Action("RetryWorkflowStep")
SendMessage = Action("SendMessage")
StartWorkflow = Action("StartWorkflow")
StopWorkflow = Action("StopWorkflow")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateWorkflow = Action("UpdateWorkflow")
UpdateWorkflowStep = Action("UpdateWorkflowStep")
UpdateWorkflowStepGroup = Action("UpdateWorkflowStepGroup")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS IoT Events"
prefix = "iotevents"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchAcknowledgeAlarm = Action("BatchAcknowledgeAlarm")
BatchDeleteDetector = Action("BatchDeleteDetector")
BatchDisableAlarm = Action("BatchDisableAlarm")
BatchEnableAlarm = Action("BatchEnableAlarm")
BatchPutMessage = Action("BatchPutMessage")
BatchResetAlarm = Action("BatchResetAlarm")
BatchSnoozeAlarm = Action("BatchSnoozeAlarm")
BatchUpdateDetector = Action("BatchUpdateDetector")
CreateAlarmModel = Action("CreateAlarmModel")
CreateDetectorModel = Action("CreateDetectorModel")
CreateInput = Action("CreateInput")
DeleteAlarmModel = Action("DeleteAlarmModel")
DeleteDetectorModel = Action("DeleteDetectorModel")
DeleteInput = Action("DeleteInput")
DescribeAlarm = Action("DescribeAlarm")
DescribeAlarmModel = Action("DescribeAlarmModel")
DescribeDetector = Action("DescribeDetector")
DescribeDetectorModel = Action("DescribeDetectorModel")
DescribeDetectorModelAnalysis = Action("DescribeDetectorModelAnalysis")
DescribeInput = Action("DescribeInput")
DescribeLoggingOptions = Action("DescribeLoggingOptions")
GetDetectorModelAnalysisResults = Action("GetDetectorModelAnalysisResults")
ListAlarmModelVersions = Action("ListAlarmModelVersions")
ListAlarmModels = Action("ListAlarmModels")
ListAlarms = Action("ListAlarms")
ListDetectorModelVersions = Action("ListDetectorModelVersions")
ListDetectorModels = Action("ListDetectorModels")
ListDetectors = Action("ListDetectors")
ListInputRoutings = Action("ListInputRoutings")
ListInputs = Action("ListInputs")
ListTagsForResource = Action("ListTagsForResource")
PutLoggingOptions = Action("PutLoggingOptions")
StartDetectorModelAnalysis = Action("StartDetectorModelAnalysis")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAlarmModel = Action("UpdateAlarmModel")
UpdateDetectorModel = Action("UpdateDetectorModel")
UpdateInput = Action("UpdateInput")
UpdateInputRouting = Action("UpdateInputRouting")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Lex"
prefix = "lex"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BuildBotLocale = Action("BuildBotLocale")
CreateBot = Action("CreateBot")
CreateBotAlias = Action("CreateBotAlias")
CreateBotChannel = Action("CreateBotChannel")
CreateBotLocale = Action("CreateBotLocale")
CreateBotVersion = Action("CreateBotVersion")
CreateCustomVocabulary = Action("CreateCustomVocabulary")
CreateExport = Action("CreateExport")
CreateIntent = Action("CreateIntent")
CreateIntentVersion = Action("CreateIntentVersion")
CreateResourcePolicy = Action("CreateResourcePolicy")
CreateSlot = Action("CreateSlot")
CreateSlotType = Action("CreateSlotType")
CreateSlotTypeVersion = Action("CreateSlotTypeVersion")
CreateUploadUrl = Action("CreateUploadUrl")
DeleteBot = Action("DeleteBot")
DeleteBotAlias = Action("DeleteBotAlias")
DeleteBotChannel = Action("DeleteBotChannel")
DeleteBotChannelAssociation = Action("DeleteBotChannelAssociation")
DeleteBotLocale = Action("DeleteBotLocale")
DeleteBotVersion = Action("DeleteBotVersion")
DeleteCustomVocabulary = Action("DeleteCustomVocabulary")
DeleteExport = Action("DeleteExport")
DeleteImport = Action("DeleteImport")
DeleteIntent = Action("DeleteIntent")
DeleteIntentVersion = Action("DeleteIntentVersion")
DeleteResourcePolicy = Action("DeleteResourcePolicy")
DeleteSession = Action("DeleteSession")
DeleteSlot = Action("DeleteSlot")
DeleteSlotType = Action("DeleteSlotType")
DeleteSlotTypeVersion = Action("DeleteSlotTypeVersion")
DeleteUtterances = Action("DeleteUtterances")
DescribeBot = Action("DescribeBot")
DescribeBotAlias = Action("DescribeBotAlias")
DescribeBotChannel = Action("DescribeBotChannel")
DescribeBotLocale = Action("DescribeBotLocale")
DescribeBotRecommendation = Action("DescribeBotRecommendation")
DescribeBotVersion = Action("DescribeBotVersion")
DescribeCustomVocabulary = Action("DescribeCustomVocabulary")
DescribeCustomVocabularyMetadata = Action("DescribeCustomVocabularyMetadata")
DescribeExport = Action("DescribeExport")
DescribeImport = Action("DescribeImport")
DescribeIntent = Action("DescribeIntent")
DescribeResourcePolicy = Action("DescribeResourcePolicy")
DescribeSlot = Action("DescribeSlot")
DescribeSlotType = Action("DescribeSlotType")
GetBot = Action("GetBot")
GetBotAlias = Action("GetBotAlias")
GetBotAliases = Action("GetBotAliases")
GetBotChannelAssociation = Action("GetBotChannelAssociation")
GetBotChannelAssociations = Action("GetBotChannelAssociations")
GetBotVersions = Action("GetBotVersions")
GetBots = Action("GetBots")
GetBuiltinIntent = Action("GetBuiltinIntent")
GetBuiltinIntents = Action("GetBuiltinIntents")
GetBuiltinSlotTypes = Action("GetBuiltinSlotTypes")
GetExport = Action("GetExport")
GetImport = Action("GetImport")
GetIntent = Action("GetIntent")
GetIntentVersions = Action("GetIntentVersions")
GetIntents = Action("GetIntents")
GetMigration = Action("GetMigration")
GetMigrations = Action("GetMigrations")
GetSession = Action("GetSession")
GetSlotType = Action("GetSlotType")
GetSlotTypeVersions = Action("GetSlotTypeVersions")
GetSlotTypes = Action("GetSlotTypes")
GetUtterancesView = Action("GetUtterancesView")
ListAggregatedUtterances = Action("ListAggregatedUtterances")
ListBotAliases = Action("ListBotAliases")
ListBotChannels = Action("ListBotChannels")
ListBotLocales = Action("ListBotLocales")
ListBotRecommendations = Action("ListBotRecommendations")
ListBotVersions = Action("ListBotVersions")
ListBots = Action("ListBots")
ListBuiltInIntents = Action("ListBuiltInIntents")
ListBuiltInSlotTypes = Action("ListBuiltInSlotTypes")
ListExports = Action("ListExports")
ListImports = Action("ListImports")
ListIntents = Action("ListIntents")
ListRecommendedIntents = Action("ListRecommendedIntents")
ListSlotTypes = Action("ListSlotTypes")
ListSlots = Action("ListSlots")
ListTagsForResource = Action("ListTagsForResource")
PostContent = Action("PostContent")
PostText = Action("PostText")
PutBot = Action("PutBot")
PutBotAlias = Action("PutBotAlias")
PutIntent = Action("PutIntent")
PutSession = Action("PutSession")
PutSlotType = Action("PutSlotType")
RecognizeSpeech = Action("RecognizeSpeech")
RecognizeText = Action("RecognizeText")
RecognizeUtterance = Action("RecognizeUtterance")
SearchAssociatedTranscripts = Action("SearchAssociatedTranscripts")
StartBotRecommendation = Action("StartBotRecommendation")
StartConversation = Action("StartConversation")
StartImport = Action("StartImport")
StartMigration = Action("StartMigration")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateBot = Action("UpdateBot")
UpdateBotAlias = Action("UpdateBotAlias")
UpdateBotLocale = Action("UpdateBotLocale")
UpdateBotRecommendation = Action("UpdateBotRecommendation")
UpdateCustomVocabulary = Action("UpdateCustomVocabulary")
UpdateExport = Action("UpdateExport")
UpdateIntent = Action("UpdateIntent")
UpdateResourcePolicy = Action("UpdateResourcePolicy")
UpdateSlot = Action("UpdateSlot")
UpdateSlotType = Action("UpdateSlotType")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Amplify"
prefix = "amplify"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateApp = Action("CreateApp")
CreateBackendEnvironment = Action("CreateBackendEnvironment")
CreateBranch = Action("CreateBranch")
CreateDeployment = Action("CreateDeployment")
CreateDomainAssociation = Action("CreateDomainAssociation")
CreateWebHook = Action("CreateWebHook")
DeleteApp = Action("DeleteApp")
DeleteBackendEnvironment = Action("DeleteBackendEnvironment")
DeleteBranch = Action("DeleteBranch")
DeleteDomainAssociation = Action("DeleteDomainAssociation")
DeleteJob = Action("DeleteJob")
DeleteWebHook = Action("DeleteWebHook")
GenerateAccessLogs = Action("GenerateAccessLogs")
GetApp = Action("GetApp")
GetArtifactUrl = Action("GetArtifactUrl")
GetBackendEnvironment = Action("GetBackendEnvironment")
GetBranch = Action("GetBranch")
GetDomainAssociation = Action("GetDomainAssociation")
GetJob = Action("GetJob")
GetWebHook = Action("GetWebHook")
ListApps = Action("ListApps")
ListArtifacts = Action("ListArtifacts")
ListBackendEnvironments = Action("ListBackendEnvironments")
ListBranches = Action("ListBranches")
ListDomainAssociations = Action("ListDomainAssociations")
ListJobs = Action("ListJobs")
ListTagsForResource = Action("ListTagsForResource")
ListWebHooks = Action("ListWebHooks")
StartDeployment = Action("StartDeployment")
StartJob = Action("StartJob")
StopJob = Action("StopJob")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateApp = Action("UpdateApp")
UpdateBranch = Action("UpdateBranch")
UpdateDomainAssociation = Action("UpdateDomainAssociation")
UpdateWebHook = Action("UpdateWebHook")
